package com.ihaoin.hooloo.device.adapter;

import android.content.Context;
import android.view.LayoutInflater;
import android.view.View;
import android.view.ViewGroup;
import android.widget.ImageView;
import android.widget.LinearLayout;
import android.widget.TextView;

import com.bumptech.glide.Glide;
import com.bumptech.glide.load.resource.bitmap.RoundedCorners;
import com.bumptech.glide.request.RequestOptions;
import com.chad.library.adapter.base.BaseSectionQuickAdapter;
import com.chad.library.adapter.base.BaseViewHolder;
import com.ihaoin.hooloo.device.R;
import com.ihaoin.hooloo.device.config.Base;
import com.ihaoin.hooloo.device.data.ScrollBean;
import com.ihaoin.hooloo.device.data.vo.Goods;
import com.ihaoin.hooloo.device.data.vo.Sku;
import com.ihaoin.hooloo.device.util.CollectionUtils;
import com.ihaoin.hooloo.device.util.StringUtils;
import com.ihaoin.hooloo.device.util.Utils;

import java.util.Arrays;
import java.util.List;
import java.util.Optional;

public class GoodsAdapter extends BaseSectionQuickAdapter<ScrollBean, BaseViewHolder> {
    private Context mContext;

    public GoodsAdapter(Context context, int layoutResId, int sectionHeadResId) {
        super(layoutResId, sectionHeadResId, null);
        this.mContext = context;
    }

    @Override
    protected void convertHead(BaseViewHolder helper, ScrollBean item) {
        helper.setText(R.id.txt_category, item.header);
    }

    @Override
    protected void convert(BaseViewHolder helper, ScrollBean item) {
        ScrollBean.ScrollItemBean t = item.t;
        Goods goods = (Goods) t.getObject();
        helper.setText(R.id.txt_name, goods.getName());
        if (StringUtils.isEmpty(goods.getDesc())) {
            helper.setGone(R.id.txt_intro, false);
        } else {
            helper.setGone(R.id.txt_intro, true);
            helper.setText(R.id.txt_intro, goods.getDesc());
        }

        if (CollectionUtils.isEmpty(goods.getTags())) {
            helper.setGone(R.id.layout_tags, false);
        } else {
            helper.setGone(R.id.layout_tags, true);
            LinearLayout layoutTag = helper.getView(R.id.layout_tags);
            layoutTag.removeAllViews();
            goods.getTags().forEach(x -> {
                View tagView = LayoutInflater.from(mContext).inflate(R.layout.item_tag, null);
                ((TextView) tagView.findViewById(R.id.txt_tag)).setText(x);
                layoutTag.addView(tagView);
            });
        }


        ImageView imgThumbnail = helper.getView(R.id.img_thumbnail);
        RoundedCorners roundedCorners = new RoundedCorners(5);
        RequestOptions options = RequestOptions.bitmapTransform(roundedCorners);
        Glide.with(mContext).load(goods.getPics().getThumbnail()).apply(options).into(imgThumbnail);

        Sku sku = getSku(goods.getSkus());

        if (sku == null) {
            helper.setGone(R.id.txt_sellout, true);
            helper.setGone(R.id.butn_add, false);
        } else {
            helper.setGone(R.id.txt_sellout, false);
            helper.setGone(R.id.butn_add, true);
            View butnAdd = helper.getView(R.id.butn_add);
            butnAdd.setOnClickListener(v -> Utils.sendAddGoodsBroadcast(mContext, goods, sku, 1));

            ViewGroup layoutItem = helper.getView(R.id.layout_item);
            Utils.setTouchDelegate(layoutItem, Arrays.asList(butnAdd), 15);
//            butnAdd.post(() -> {
//                Rect bounds = new Rect();
//                ViewGroupUtils.getDescendantRect(layoutItem, butnAdd, bounds);
//                bounds.top -= Utils.dpToPx(mContext, 15);
//                bounds.left -= Utils.dpToPx(mContext, 15);
//                bounds.bottom += Utils.dpToPx(mContext, 15);
//                bounds.right += Utils.dpToPx(mContext, 15);
//                layoutItem.setTouchDelegate(new TouchDelegate(bounds, butnAdd));
//            });
        }

        View layoutItem = helper.getView(R.id.layout_item);
        layoutItem.setOnClickListener(v -> Utils.showGoodsDetail(mContext, goods));
    }

    /** 获取SKU，优选获取默认的SKU */
    private Sku getSku(List<Sku> skus) {
        if (CollectionUtils.isEmpty(skus)) {
            return null;
        }
        Optional<Sku> optional = skus.stream().filter(x -> Base.TRUE.equals(x.getIsDefault()) && Base.TRUE.equals(x.getState())).findAny();
        if (optional.isPresent()) {
            return optional.get();
        }
        optional = skus.stream().filter(x -> Base.TRUE.equals(x.getState())).findAny();
        if (optional.isPresent()) {
            return optional.get();
        }
        return null;
    }
}
