package com.ihaoin.hooloo.device.util;

import android.annotation.SuppressLint;
import android.content.Context;
import android.content.Intent;
import android.graphics.Rect;
import android.util.DisplayMetrics;
import android.view.TouchDelegate;
import android.view.View;
import android.view.ViewGroup;

import androidx.coordinatorlayout.widget.ViewGroupUtils;

import com.ihaoin.hooloo.device.component.TouchDelegateComposite;
import com.ihaoin.hooloo.device.data.TrolleyGoods;
import com.ihaoin.hooloo.device.data.po.ConfirmGoods;
import com.ihaoin.hooloo.device.data.vo.Goods;
import com.ihaoin.hooloo.device.data.vo.Sku;
import com.ihaoin.hooloo.device.view.ConfirmOrderDialog;
import com.ihaoin.hooloo.device.view.GoodsDetailDialog;
import com.ihaoin.hooloo.device.view.TipsDialog;

import java.util.Arrays;
import java.util.List;
import java.util.stream.Collectors;

public class Utils {
    public static String ADD_GOODS_ACTION = "ADD_GOODS_ACTION";
    public static String GOODS_CHANGED_ACTION = "GOODS_CHANGED_ACTION";
    public static String CLEAR_GOODS_ACTION = "CLEAR_GOODS_ACTION";

    public static void sendAddGoodsBroadcast(Context context, Goods goods, Sku sku, Integer count) {
        Intent intent = new Intent();
        intent.setAction(Utils.ADD_GOODS_ACTION);
        intent.putExtra("goods", goods);
        intent.putExtra("sku", sku);
        intent.putExtra("count", count);
        context.sendBroadcast(intent);
    }

    public static void sendGoodsChnagedBroadcast(Context context) {
        Intent intent = new Intent();
        intent.setAction(Utils.GOODS_CHANGED_ACTION);
        context.sendBroadcast(intent);
    }

    public static void sendClearGoodsBroadcast(Context context) {
        Intent intent = new Intent();
        intent.setAction(Utils.CLEAR_GOODS_ACTION);
        context.sendBroadcast(intent);
    }

    public static void showGoodsDetail(Context context, Goods goods) {
        GoodsDetailDialog dialog = new GoodsDetailDialog(context, goods);
        dialog.show();
    }

    public static void showTips(Context context) {
        TipsDialog dialog = new TipsDialog(context);
        dialog.show();
    }

    public static void showConfirmOrder(Context context, List<TrolleyGoods> trolleyGoods) {
        ConfirmOrderDialog dialog = new ConfirmOrderDialog(context);
        dialog.setGoods(trolleyGoods);
        dialog.show();
    }

    public static void showConfirmOrder(Context context, Goods goods, Sku sku, Integer count) {
        ConfirmOrderDialog dialog = new ConfirmOrderDialog(context);
        dialog.setGoods(goods, sku, count);
        dialog.show();
    }

    /**
     * 获得资源 dimens (dp)
     *
     * @param context
     * @param id      资源id
     * @return
     */
    public static float getDimens(Context context, int id) {
        DisplayMetrics dm = context.getResources().getDisplayMetrics();
        float px = context.getResources().getDimension(id);
        return px / dm.density;
    }

    /**
     * dp转px
     *
     * @param context
     * @param dp
     * @return
     */
    public static int dpToPx(Context context, float dp) {
        DisplayMetrics displayMetrics = context.getResources().getDisplayMetrics();
        return (int) ((dp * displayMetrics.density) + 0.5f);
    }

    public static List<ConfirmGoods> translate(List<TrolleyGoods> trolleyGoods) {
        if (CollectionUtils.isEmpty(trolleyGoods)) {
            return null;
        }
        return trolleyGoods.stream().map(x -> {
            ConfirmGoods g = new ConfirmGoods();
            g.setGoodsId(x.getGoodId());
            g.setSkuId(x.getSkuId());
            g.setCount(x.getCount());
            return g;
        }).collect(Collectors.toList());
    }

    public static List<ConfirmGoods> translate(Goods goods, Sku sku, Integer count) {
        if (goods == null || sku == null || count <= 0) {
            return null;
        }
        ConfirmGoods g = new ConfirmGoods();
        g.setGoodsId(goods.getGoodId());
        g.setSkuId(sku.getSkuId());
        g.setCount(count);
        return Arrays.asList(g);
    }

    @SuppressLint("RestrictedApi")
    public static void setTouchDelegate(ViewGroup group, List<View> views, Integer dp) {
        Integer px = Utils.dpToPx(group.getContext(), dp);
        TouchDelegateComposite composite = new TouchDelegateComposite(group);
        views.forEach(view -> view.post(() -> {
            Rect bounds = new Rect();
            ViewGroupUtils.getDescendantRect(group, view, bounds);
            bounds.top -= px;
            bounds.left -= px;
            bounds.bottom += px;
            bounds.right += px;
            composite.addDelegate(new TouchDelegate(bounds, view));
        }));
        group.setTouchDelegate(composite);
    }
}
