package com.ihaoin.hooloo.device.view;

import android.app.Dialog;
import android.content.Context;
import android.content.DialogInterface;
import android.graphics.drawable.AnimationDrawable;
import android.os.Bundle;
import android.os.Handler;
import android.os.Message;
import android.util.Log;
import android.view.View;
import android.widget.TextView;
import android.widget.Toast;

import androidx.annotation.NonNull;

import com.fasterxml.jackson.databind.ObjectMapper;
import com.ihaoin.hooloo.device.R;
import com.ihaoin.hooloo.device.config.AppConfig;
import com.ihaoin.hooloo.device.data.TrolleyGoods;
import com.ihaoin.hooloo.device.data.po.ConfirmGoods;
import com.ihaoin.hooloo.device.data.po.ConfirmOrder;
import com.ihaoin.hooloo.device.data.vo.Goods;
import com.ihaoin.hooloo.device.data.vo.Sku;
import com.ihaoin.hooloo.device.network.HttpUtil;
import com.ihaoin.hooloo.device.util.Utils;

import java.util.ArrayList;
import java.util.List;

public class ConfirmOrderDialog extends Dialog {
    private List<ConfirmGoods> goods = new ArrayList<>();
    private UIHandler uiHandler;
    private ConfirmOrderHandler confirmOrderHandler;
    private Thread expireThread;
    private Thread returnThread;
    private final Integer EXPIRE_TIMES = 60;
    private final Integer RETURN_TIMES = 5;

    private View layoutContent;
    private View layoutConfirm;
    private View layoutSucceed;
    private TextView txtExpire;
    private TextView txtReturn;
    private View butnClose;
    private View loading;

    public ConfirmOrderDialog(@NonNull Context context) {
        super(context);
    }

    public void setGoods(List<TrolleyGoods> trolleyGoods) {
        this.goods = Utils.translate(trolleyGoods);
    }

    public void setGoods(Goods goods, Sku sku, Integer count) {
        this.goods = Utils.translate(goods, sku, count);
    }

    @Override
    protected void onCreate(Bundle savedInstanceState) {
        super.onCreate(savedInstanceState);
        this.setContentView(R.layout.view_confirm_order);
        initViews();

    }

    private void initViews() {
        layoutContent = findViewById(R.id.layout_content);
        layoutConfirm = findViewById(R.id.layout_confirm);
        layoutSucceed = findViewById(R.id.layout_succeed);
        txtExpire = findViewById(R.id.txt_expire);
        txtReturn = findViewById(R.id.txt_return);
        butnClose = findViewById(R.id.butn_close);
        loading = findViewById(R.id.loading);

        layoutConfirm.setVisibility(View.VISIBLE);
        layoutSucceed.setVisibility(View.GONE);

        butnClose.setOnClickListener(x -> dismiss());
        uiHandler = new UIHandler();

        setOnDismissListener(dismissListener);

        setCancelable(false);
        setCanceledOnTouchOutside(false);

        postConfirmOrder();
    }

    private void postConfirmOrder() {
        try {
            startLoading();

            confirmOrderHandler = new ConfirmOrderHandler();
            HttpUtil.postConfirmOrder(genJson(), confirmOrderHandler);
        } catch (Exception e) {
            e.printStackTrace();
            Toast.makeText(getContext(), R.string.error_get_qrcode, Toast.LENGTH_LONG).show();
            dismiss();
        }
    }

    private void startLoading() {
        layoutContent.setVisibility(View.INVISIBLE);
        loading.setVisibility(View.VISIBLE);

        AnimationDrawable animationDrawable = (AnimationDrawable) loading.getBackground();
        animationDrawable.start();
    }

    private void stopLoading() {
        layoutContent.setVisibility(View.VISIBLE);
        loading.setVisibility(View.INVISIBLE);

        AnimationDrawable animationDrawable = (AnimationDrawable) loading.getBackground();
        animationDrawable.stop();
    }

    private String genJson() {
        try {
            ConfirmOrder confirmOrder = new ConfirmOrder();
            confirmOrder.setMachineCode(AppConfig.MACHINE_CODE);
            confirmOrder.setScreenNo(AppConfig.SCREEN_NO);
            confirmOrder.setGoods(goods);

            ObjectMapper objectMapper = new ObjectMapper();
            return objectMapper.writeValueAsString(confirmOrder);
        } catch (Exception e) {
            e.printStackTrace();
        }
        return null;
    }

    OnDismissListener dismissListener = new OnDismissListener() {
        @Override
        public void onDismiss(DialogInterface dialog) {
            if (expireThread != null) {
                expireThread.interrupt();
            }
            if (returnThread != null) {
                returnThread.interrupt();
            }
            if (uiHandler != null) {
                uiHandler.removeCallbacksAndMessages(null);
                uiHandler = null;
            }
            if (confirmOrderHandler != null) {
                confirmOrderHandler.removeCallbacksAndMessages(null);
                confirmOrderHandler = null;
            }
        }
    };

    private void startExpireThread() {
        expireThread = new Thread() {
            @Override
            public void run() {
                try {
                    for (int i = EXPIRE_TIMES; i >= 0; i--) {
                        if (uiHandler == null) {
                            return;
                        }
                        Message msg = new Message();
                        msg.what = 0;// 二维码失效倒计时
                        msg.obj = i;
                        uiHandler.sendMessage(msg);
                        Thread.sleep(1000);
                    }
                } catch (InterruptedException e) {
                    e.printStackTrace();
                }
            }
        };
        expireThread.start();
    }

    private void startReturnThread() {
        returnThread = new Thread() {
            @Override
            public void run() {
                try {
                    for (int i = RETURN_TIMES; i >= 0; i--) {
                        if (uiHandler == null) {
                            return;
                        }
                        Message msg = new Message();
                        msg.what = 1;// 扫码成功倒计时
                        msg.obj = i;
                        uiHandler.sendMessage(msg);
                        Thread.sleep(1000);
                    }
                } catch (InterruptedException e) {
                    e.printStackTrace();
                }
            }
        };
        returnThread.start();
    }

    class UIHandler extends Handler {
        @Override
        public void handleMessage(@NonNull Message msg) {
            switch (msg.what) {
                case 0:
                    Integer expireTimes = (Integer) msg.obj;
                    txtExpire.setText(getContext().getString(R.string.expire_times, expireTimes.toString()));
                    if (expireTimes <= 0) {
                        Utils.sendClearGoodsBroadcast(getContext());
                        dismiss();
                    }
                    break;
                case 1:
                    Integer returnTimes = (Integer) msg.obj;
                    txtReturn.setText(getContext().getString(R.string.scan_succeed, returnTimes.toString()));
                    if (returnTimes <= 0) {
                        Utils.sendClearGoodsBroadcast(getContext());
                        dismiss();
                    }
                    break;
            }
        }
    }

    class ConfirmOrderHandler extends Handler {
        @Override
        public void handleMessage(@NonNull Message msg) {
            stopLoading();
            if (msg.what == 0) {
                Toast.makeText(getContext(), R.string.error_get_qrcode, Toast.LENGTH_LONG).show();
                dismiss();
                return;
            }

            String s = (String) msg.obj;
            Log.d("HTTP", s);
            startExpireThread();
        }
    }
}
