package com.ihaoin.hooloo.device.view;

import android.app.Activity;
import android.content.BroadcastReceiver;
import android.content.Context;
import android.content.Intent;
import android.content.IntentFilter;
import android.graphics.Rect;
import android.os.Bundle;
import android.util.Log;
import android.view.View;
import android.view.WindowManager;
import android.widget.RadioButton;
import android.widget.RadioGroup;
import android.widget.TextView;

import androidx.annotation.NonNull;
import androidx.recyclerview.widget.GridLayoutManager;
import androidx.recyclerview.widget.LinearLayoutManager;
import androidx.recyclerview.widget.RecyclerView;

import com.fasterxml.jackson.core.JsonProcessingException;
import com.fasterxml.jackson.databind.ObjectMapper;
import com.ihaoin.hooloo.device.R;
import com.ihaoin.hooloo.device.adapter.GoodsAdapter;
import com.ihaoin.hooloo.device.adapter.RecommendAdapter;
import com.ihaoin.hooloo.device.data.vo.Category;
import com.ihaoin.hooloo.device.data.vo.Goods;
import com.ihaoin.hooloo.device.data.vo.Pics;
import com.ihaoin.hooloo.device.data.vo.Recommend;
import com.ihaoin.hooloo.device.data.ScrollBean;
import com.ihaoin.hooloo.device.data.vo.Sku;
import com.ihaoin.hooloo.device.util.Utils;

import java.util.ArrayList;
import java.util.Arrays;
import java.util.List;

public class LauncherActivity extends Activity {

    private RadioGroup groupCategory;
    private RecyclerView recGoods;
    private RecyclerView recRecommends;
//    private TextView rightTitle;

    private List<Recommend> recommends;
    private List<ScrollBean> scrollRecommends;
    private List<Category> categorys;
    private List<ScrollBean> scrollGoods;

    private GridLayoutManager recommendManager;
    private LinearLayoutManager goodsLayoutManager;

    private RecommendAdapter recommendAdapter;
    private GoodsAdapter goodsAdapter;
    //右侧title在数据中所对应的position集合
    private List<Integer> tPosition = new ArrayList<>();
    //记录商品当前可见的第一个item的position
    private int first = 0;
    private Context mContext;
    private TrolleyView trolleyView;

    @Override
    protected void onCreate(Bundle savedInstanceState) {
        super.onCreate(savedInstanceState);
        setContentView(R.layout.activity_launcher);
        getWindow().setFlags(WindowManager.LayoutParams.FLAG_FULLSCREEN, WindowManager.LayoutParams.FLAG_FULLSCREEN);

        mContext = this;

        trolleyView = findViewById(R.id.view_trolley);
        groupCategory = findViewById(R.id.group_category);
        recGoods = findViewById(R.id.rec_right);
        recRecommends = findViewById(R.id.rec_recommend);

        try {
            initData();
        } catch (JsonProcessingException e) {
            e.printStackTrace();
        }

        initRecommends();
        initCategorys();
        initGoods();

        this.registerdTrolleyReceiver();
    }

    private void initRecommends() {
        recommendManager = new GridLayoutManager(mContext, 2);
        recommendManager.setSpanSizeLookup(new MySpanSizeLookup());
        recRecommends.addItemDecoration(new RecyclerView.ItemDecoration() {
            @Override
            public void getItemOffsets(@NonNull Rect outRect, @NonNull View view, @NonNull RecyclerView parent, @NonNull RecyclerView.State state) {
                outRect.left = Utils.dpToPx(LauncherActivity.this, 10);
                outRect.bottom = Utils.dpToPx(LauncherActivity.this, 10);
            }
        });

        if (recommendAdapter == null) {
            recommendAdapter = new RecommendAdapter(this, R.layout.item_recommend, R.layout.item_logo);
            recRecommends.setAdapter(recommendAdapter);
            recRecommends.setLayoutManager(recommendManager);
        } else {
            recommendAdapter.notifyDataSetChanged();
        }

        scrollRecommends = new ArrayList<>();
        ScrollBean header = new ScrollBean(true, null);
        scrollRecommends.add(header);
        recommends.forEach(x -> scrollRecommends.add(new ScrollBean(new ScrollBean.ScrollItemBean(x, null))));

        recommendAdapter.setNewData(scrollRecommends);
    }

    class MySpanSizeLookup extends GridLayoutManager.SpanSizeLookup {
        @Override
        public int getSpanSize(int position) {
            Log.d("TEST", "position:" + position);
            if (position == 0 || position == 1) {
                return 2;
            }
            return 1;
        }
    }

    private void initGoods() {
        goodsLayoutManager = new LinearLayoutManager(mContext);
        if (goodsAdapter == null) {
            goodsAdapter = new GoodsAdapter(this, R.layout.item_goods, R.layout.item_goods_category);
            recGoods.setAdapter(goodsAdapter);
            recGoods.setLayoutManager(goodsLayoutManager);
        } else {
            goodsAdapter.notifyDataSetChanged();
        }
        goodsAdapter.setNewData(scrollGoods);

        // 商品滚动时同时设置分类变化
        recGoods.addOnScrollListener(new RecyclerView.OnScrollListener() {
            @Override
            public void onScrolled(@NonNull RecyclerView recyclerView, int dx, int dy) {
                super.onScrolled(recyclerView, dx, dy);
                // 商品滚动时获取当前显示的第一个商品的分类名称
                int firstPosition = goodsLayoutManager.findFirstVisibleItemPosition();
                String title = "";
                if (first != firstPosition && firstPosition >= 0) {
                    //给first赋值
                    first = firstPosition;

                    //判断如果右侧可见的第一个item是否是header,设置相应的值
                    if (scrollGoods.get(first).isHeader) {
                        title = scrollGoods.get(first).header;
                    } else {
                        title = scrollGoods.get(first).t.getType();
                    }
                }

                // 遍历分类列表，设置选中分类
                for (Category category : categorys) {
                    if (category.getName().equals(title)) {
                        if (groupCategory.getCheckedRadioButtonId() == category.getId()) {
                            break;
                        }
                        groupCategory.check(category.getId());
                    }
                }
            }
        });
    }

    private void initCategorys() {
        groupCategory.removeAllViews();
        if (categorys == null || categorys.isEmpty()) {
            return;
        }

        categorys.forEach(category -> {
            RadioGroup.LayoutParams layoutParams = new RadioGroup.LayoutParams(RadioGroup.LayoutParams.MATCH_PARENT, RadioGroup.LayoutParams.WRAP_CONTENT);
            RadioButton view = (RadioButton) this.getLayoutInflater().inflate(R.layout.item_category, null);
            view.setText(category.getName());
            view.setId(category.getId());
            view.setTag(category);
            groupCategory.addView(view, layoutParams);

            view.setOnClickListener(v -> {
                Integer checkedId = v.getId();
                Category category1 = (Category) groupCategory.findViewById(checkedId).getTag();
                int position = categorys.indexOf(category1);
                goodsLayoutManager.scrollToPositionWithOffset(tPosition.get(position), 0);

                for (int i = 0; i < groupCategory.getChildCount(); i++) {
                    View child = groupCategory.getChildAt(i);
                    if (!(child instanceof RadioButton)) {
                        continue;
                    }
                    RadioButton butn = (RadioButton) child;
                    if (butn.getId() == checkedId) {
                        butn.getPaint().setFakeBoldText(true);
                    } else {
                        butn.getPaint().setFakeBoldText(false);
                    }
                }
            });
        });

        // 添加温馨提示
        RadioGroup.LayoutParams layoutParams = new RadioGroup.LayoutParams(RadioGroup.LayoutParams.MATCH_PARENT, RadioGroup.LayoutParams.WRAP_CONTENT);
        TextView view = (TextView) this.getLayoutInflater().inflate(R.layout.item_tips, null);
        groupCategory.addView(view, layoutParams);
        view.setOnClickListener(v -> Utils.showTips(LauncherActivity.this));

        groupCategory.check(categorys.get(0).getId());
    }

    //获取数据(若请求服务端数据,请求到的列表需有序排列)
    private void initData() throws JsonProcessingException {
        ObjectMapper objectMapper = new ObjectMapper();

        Pics p1 = new Pics();
        Pics p2 = new Pics();
        Pics p3 = new Pics();

        p1.setThumbnail("https://img1.baidu.com/it/u=3426268058,1014861135&fm=253&fmt=auto&app=138&f=JPEG?w=190&h=118");
        p2.setThumbnail("https://ss2.baidu.com/-vo3dSag_xI4khGko9WTAnF6hhy/baike/s%3D220/sign=6e742a00ff03918fd3d13ac8613c264b/d439b6003af33a87e4037dface5c10385243b5e7.jpg");
        p3.setThumbnail("https://gimg2.baidu.com/image_search/src=http%3A%2F%2Fimg.jj20.com%2Fup%2Fallimg%2Ftx18%2F0217202021933.jpg&refer=http%3A%2F%2Fimg.jj20.com&app=2002&size=f9999,10000&q=a80&n=0&g=0n&fmt=auto?sec=1653792863&t=ec8778ab3ff1891dbd8e715956097181");
//        Goods g1 = new Goods(1, "冰茶咖啡1", p1);
//        Goods g2 = new Goods(2, "冰茶咖啡2", p2);
//        Goods g3 = new Goods(3, "冰茶咖啡3", p3);
//        Goods g4 = new Goods(4, "冰茶咖啡4", p1);
//        Goods g5 = new Goods(5, "冰茶咖啡5", p2);
//        Goods g6 = new Goods(6, "冰茶咖啡6", p3);
//        Goods g7 = new Goods(7, "冰茶咖啡7", p3);
//        Goods g8 = new Goods(7, "冰茶咖啡8", p3);
//        Goods g9 = new Goods(7, "冰茶咖啡9", p3);
//        Goods g10 = new Goods(7, "冰茶咖啡10", p3);
//        Goods g11 = new Goods(7, "冰茶咖啡11", p3);
//        Goods g12 = new Goods(7, "冰茶咖啡12", p3);
//        Goods g13 = new Goods(7, "冰茶咖啡13", p3);
//        Goods g14 = new Goods(7, "冰茶咖啡14", p3);
//        Goods g15 = new Goods(7, "冰茶咖啡15", p3);
//        Goods g16 = new Goods(7, "冰茶咖啡16", p3);
//        Goods g17 = new Goods(7, "冰茶咖啡17", p3);
//        Goods g18 = new Goods(7, "冰茶咖啡18", p3);
//        Goods g19 = new Goods(7, "冰茶咖啡19", p3);
//        Goods g20 = new Goods(7, "冰茶咖啡20", p3);
//        Goods g21 = new Goods(7, "冰茶咖啡21", p3);
//        Goods g22 = new Goods(7, "冰茶咖啡22", p3);
        Goods g1 = objectMapper.readValue("{\"goodId\":100,\"name\":\"冰茶咖啡\",\"desc\":\"好喝的咖啡好喝的咖啡好喝的咖啡好喝的咖啡好喝的咖啡好喝的咖啡\",\"price\":10.9,\"discount\":9.9,\"pics\":{\"thumbnail\":\"https://img1.baidu.com/it/u=3426268058,1014861135&fm=253&fmt=auto&app=138&f=JPEG?w=190&h=118\",\"introImages\":[\"https://nimg.ws.126.net/?url=http%3A%2F%2Fdingyue.ws.126.net%2F2021%2F0916%2F2ff161bap00qzik7b00aad000t700inp.png&thumbnail=660x2147483647&quality=80&type=jpg\"],\"detailImages\":[\"https://nimg.ws.126.net/?url=http%3A%2F%2Fdingyue.ws.126.net%2F2021%2F0916%2F5527f996p00qzikdu00avd000th00inp.png&thumbnail=660x2147483647&quality=80&type=jpg\",\"https://nimg.ws.126.net/?url=http%3A%2F%2Fdingyue.ws.126.net%2F2021%2F0916%2Fbe0a3f04p00qziken00cvd000te00ikp.png&thumbnail=660x2147483647&quality=80&type=jpg\"]},\"remark\":\"\",\"tags\":[\"YYDS\",\"杨幂同款\"],\"specs\":[{\"specId\":10,\"specName\":\"温度\",\"rules\":[{\"isDefault\":1,\"ruleId\":101,\"ruleName\":\"常温\",\"price\":0},{\"ruleId\":102,\"ruleName\":\"加热\",\"price\":3}]},{\"specId\":11,\"specName\":\"糖度\",\"rules\":[{\"ruleId\":114,\"ruleName\":\"无糖\",\"price\":0},{\"isDefault\":1,\"ruleId\":115,\"ruleName\":\"少糖\",\"price\":1},{\"ruleId\":116,\"ruleName\":\"多糖\",\"price\":2}]}],\"skus\":[{\"isDefault\":0,\"skuId\":1,\"state\":1,\"price\":10.9,\"discount\":9.9,\"rules\":[{\"specId\":10,\"specName\":\"温度\",\"ruleId\":101,\"ruleName\":\"常温\",\"price\":0.00},{\"specId\":11,\"specName\":\"糖度\",\"ruleId\":114,\"ruleName\":\"无糖\",\"price\":0.00}]},{\"skuId\":2,\"state\":1,\"price\":12.9,\"discount\":11.9,\"isDefault\":1,\"rules\":[{\"specId\":10,\"specName\":\"温度\",\"ruleId\":101,\"ruleName\":\"常温\",\"price\":0.00},{\"specId\":11,\"specName\":\"糖度\",\"ruleId\":115,\"ruleName\":\"少糖\",\"price\":2.00}]},{\"skuId\":3,\"state\":0,\"price\":14.9,\"discount\":13.9,\"isDefault\":0,\"rules\":[{\"specId\":10,\"specName\":\"温度\",\"ruleId\":101,\"ruleName\":\"常温\",\"price\":0.00},{\"specId\":11,\"specName\":\"糖度\",\"ruleId\":116,\"ruleName\":\"多糖\",\"price\":4.00}]},{\"isDefault\":0,\"skuId\":4,\"state\":1,\"price\":13.9,\"discount\":12.9,\"rules\":[{\"specId\":10,\"specName\":\"温度\",\"ruleId\":102,\"ruleName\":\"加热\",\"price\":3.00},{\"specId\":11,\"specName\":\"糖度\",\"ruleId\":114,\"ruleName\":\"无糖\",\"price\":0.00}]},{\"skuId\":5,\"state\":1,\"price\":15.9,\"discount\":14.9,\"isDefault\":0,\"rules\":[{\"specId\":10,\"specName\":\"温度\",\"ruleId\":102,\"ruleName\":\"加热\",\"price\":3.00},{\"specId\":11,\"specName\":\"糖度\",\"ruleId\":115,\"ruleName\":\"少糖\",\"price\":2.00}]},{\"skuId\":6,\"state\":0,\"price\":17.9,\"discount\":16.9,\"isDefault\":0,\"rules\":[{\"specId\":10,\"specName\":\"温度\",\"ruleId\":102,\"ruleName\":\"加热\",\"price\":3.00},{\"specId\":11,\"specName\":\"糖度\",\"ruleId\":116,\"ruleName\":\"多糖\",\"price\":4.00}]}]}", Goods.class);
        Goods g2 = objectMapper.readValue("{\"goodId\":100,\"name\":\"冰茶咖啡\",\"price\":29.9,\"discount\":19.9,\"pics\":{\"thumbnail\":\"https://img1.baidu.com/it/u=3426268058,1014861135&fm=253&fmt=auto&app=138&f=JPEG?w=190&h=118\",\"introImages\":[\"https://nimg.ws.126.net/?url=http%3A%2F%2Fdingyue.ws.126.net%2F2021%2F0916%2F2ff161bap00qzik7b00aad000t700inp.png&thumbnail=660x2147483647&quality=80&type=jpg\"],\"detailImages\":[\"https://nimg.ws.126.net/?url=http%3A%2F%2Fdingyue.ws.126.net%2F2021%2F0916%2F5527f996p00qzikdu00avd000th00inp.png&thumbnail=660x2147483647&quality=80&type=jpg\",\"https://nimg.ws.126.net/?url=http%3A%2F%2Fdingyue.ws.126.net%2F2021%2F0916%2Fbe0a3f04p00qziken00cvd000te00ikp.png&thumbnail=660x2147483647&quality=80&type=jpg\"]},\"desc\":\"\",\"remark\":\"\",\"tags\":[\"YYDS\",\"杨幂同款\"],\"specs\":[{\"specId\":1,\"specName\":\"温度\",\"rules\":[{\"ruleId\":1,\"ruleName\":\"常温\",\"price\":0},{\"ruleId\":2,\"ruleName\":\"加冰\",\"price\":2},{\"ruleId\":3,\"ruleName\":\"加热\",\"price\":3}]},{\"specId\":2,\"specName\":\"糖度\",\"rules\":[{\"ruleId\":4,\"ruleName\":\"无糖\",\"price\":0},{\"ruleId\":5,\"ruleName\":\"少糖\",\"price\":1},{\"ruleId\":6,\"ruleName\":\"多糖\",\"price\":2}]}],\"skus\":[{\"skuId\":1,\"state\":1,\"rules\":[{\"specId\":1,\"specName\":\"温度\",\"ruleId\":1,\"ruleName\":\"常温\",\"price\":0.00},{\"specId\":2,\"specName\":\"糖度\",\"ruleId\":3,\"ruleName\":\"无糖\",\"price\":0.00}]},{\"skuId\":1,\"state\":1,\"rules\":[{\"specId\":1,\"specName\":\"温度\",\"ruleId\":2,\"ruleName\":\"冰\",\"price\":2.00},{\"specId\":2,\"specName\":\"糖度\",\"ruleId\":3,\"ruleName\":\"无糖\",\"price\":0.00}]},{\"skuId\":1,\"state\":1,\"rules\":[{\"specId\":1,\"specName\":\"温度\",\"ruleId\":1,\"ruleName\":\"常温\",\"price\":0.00},{\"specId\":2,\"specName\":\"糖度\",\"ruleId\":3,\"ruleName\":\"加糖\",\"price\":2.00}]},{\"skuId\":1,\"state\":1,\"rules\":[{\"specId\":1,\"specName\":\"温度\",\"ruleId\":1,\"ruleName\":\"冰\",\"price\":2.00},{\"specId\":2,\"specName\":\"糖度\",\"ruleId\":3,\"ruleName\":\"加糖\",\"price\":4.00}]}]}", Goods.class);
        Goods g3 = objectMapper.readValue("{\"goodId\":100,\"name\":\"冰茶咖啡\",\"price\":29.9,\"discount\":19.9,\"pics\":{\"thumbnail\":\"https://img1.baidu.com/it/u=3426268058,1014861135&fm=253&fmt=auto&app=138&f=JPEG?w=190&h=118\",\"introImages\":[\"https://nimg.ws.126.net/?url=http%3A%2F%2Fdingyue.ws.126.net%2F2021%2F0916%2F2ff161bap00qzik7b00aad000t700inp.png&thumbnail=660x2147483647&quality=80&type=jpg\"],\"detailImages\":[\"https://nimg.ws.126.net/?url=http%3A%2F%2Fdingyue.ws.126.net%2F2021%2F0916%2F5527f996p00qzikdu00avd000th00inp.png&thumbnail=660x2147483647&quality=80&type=jpg\",\"https://nimg.ws.126.net/?url=http%3A%2F%2Fdingyue.ws.126.net%2F2021%2F0916%2Fbe0a3f04p00qziken00cvd000te00ikp.png&thumbnail=660x2147483647&quality=80&type=jpg\"]},\"desc\":\"\",\"remark\":\"\",\"tags\":[\"YYDS\",\"杨幂同款\"],\"specs\":[{\"specId\":1,\"specName\":\"温度\",\"rules\":[{\"ruleId\":1,\"ruleName\":\"常温\",\"price\":0},{\"ruleId\":2,\"ruleName\":\"加冰\",\"price\":2},{\"ruleId\":3,\"ruleName\":\"加热\",\"price\":3}]},{\"specId\":2,\"specName\":\"糖度\",\"rules\":[{\"ruleId\":4,\"ruleName\":\"无糖\",\"price\":0},{\"ruleId\":5,\"ruleName\":\"少糖\",\"price\":1},{\"ruleId\":6,\"ruleName\":\"多糖\",\"price\":2}]}],\"skus\":[{\"skuId\":1,\"state\":1,\"rules\":[{\"specId\":1,\"specName\":\"温度\",\"ruleId\":1,\"ruleName\":\"常温\",\"price\":0.00},{\"specId\":2,\"specName\":\"糖度\",\"ruleId\":3,\"ruleName\":\"无糖\",\"price\":0.00}]},{\"skuId\":1,\"state\":1,\"rules\":[{\"specId\":1,\"specName\":\"温度\",\"ruleId\":2,\"ruleName\":\"冰\",\"price\":2.00},{\"specId\":2,\"specName\":\"糖度\",\"ruleId\":3,\"ruleName\":\"无糖\",\"price\":0.00}]},{\"skuId\":1,\"state\":1,\"rules\":[{\"specId\":1,\"specName\":\"温度\",\"ruleId\":1,\"ruleName\":\"常温\",\"price\":0.00},{\"specId\":2,\"specName\":\"糖度\",\"ruleId\":3,\"ruleName\":\"加糖\",\"price\":2.00}]},{\"skuId\":1,\"state\":1,\"rules\":[{\"specId\":1,\"specName\":\"温度\",\"ruleId\":1,\"ruleName\":\"冰\",\"price\":2.00},{\"specId\":2,\"specName\":\"糖度\",\"ruleId\":3,\"ruleName\":\"加糖\",\"price\":4.00}]}]}", Goods.class);
        Goods g4 = objectMapper.readValue("{\"goodId\":100,\"name\":\"冰茶咖啡\",\"price\":29.9,\"discount\":19.9,\"pics\":{\"thumbnail\":\"https://img1.baidu.com/it/u=3426268058,1014861135&fm=253&fmt=auto&app=138&f=JPEG?w=190&h=118\",\"introImages\":[\"https://nimg.ws.126.net/?url=http%3A%2F%2Fdingyue.ws.126.net%2F2021%2F0916%2F2ff161bap00qzik7b00aad000t700inp.png&thumbnail=660x2147483647&quality=80&type=jpg\"],\"detailImages\":[\"https://nimg.ws.126.net/?url=http%3A%2F%2Fdingyue.ws.126.net%2F2021%2F0916%2F5527f996p00qzikdu00avd000th00inp.png&thumbnail=660x2147483647&quality=80&type=jpg\",\"https://nimg.ws.126.net/?url=http%3A%2F%2Fdingyue.ws.126.net%2F2021%2F0916%2Fbe0a3f04p00qziken00cvd000te00ikp.png&thumbnail=660x2147483647&quality=80&type=jpg\"]},\"desc\":\"\",\"remark\":\"\",\"tags\":[\"YYDS\",\"杨幂同款\"],\"specs\":[{\"specId\":1,\"specName\":\"温度\",\"rules\":[{\"ruleId\":1,\"ruleName\":\"常温\",\"price\":0},{\"ruleId\":2,\"ruleName\":\"加冰\",\"price\":2},{\"ruleId\":3,\"ruleName\":\"加热\",\"price\":3}]},{\"specId\":2,\"specName\":\"糖度\",\"rules\":[{\"ruleId\":4,\"ruleName\":\"无糖\",\"price\":0},{\"ruleId\":5,\"ruleName\":\"少糖\",\"price\":1},{\"ruleId\":6,\"ruleName\":\"多糖\",\"price\":2}]}],\"skus\":[{\"skuId\":1,\"state\":1,\"rules\":[{\"specId\":1,\"specName\":\"温度\",\"ruleId\":1,\"ruleName\":\"常温\",\"price\":0.00},{\"specId\":2,\"specName\":\"糖度\",\"ruleId\":3,\"ruleName\":\"无糖\",\"price\":0.00}]},{\"skuId\":1,\"state\":1,\"rules\":[{\"specId\":1,\"specName\":\"温度\",\"ruleId\":2,\"ruleName\":\"冰\",\"price\":2.00},{\"specId\":2,\"specName\":\"糖度\",\"ruleId\":3,\"ruleName\":\"无糖\",\"price\":0.00}]},{\"skuId\":1,\"state\":1,\"rules\":[{\"specId\":1,\"specName\":\"温度\",\"ruleId\":1,\"ruleName\":\"常温\",\"price\":0.00},{\"specId\":2,\"specName\":\"糖度\",\"ruleId\":3,\"ruleName\":\"加糖\",\"price\":2.00}]},{\"skuId\":1,\"state\":1,\"rules\":[{\"specId\":1,\"specName\":\"温度\",\"ruleId\":1,\"ruleName\":\"冰\",\"price\":2.00},{\"specId\":2,\"specName\":\"糖度\",\"ruleId\":3,\"ruleName\":\"加糖\",\"price\":4.00}]}]}", Goods.class);
        Goods g5 = objectMapper.readValue("{\"goodId\":100,\"name\":\"冰茶咖啡\",\"price\":29.9,\"discount\":19.9,\"pics\":{\"thumbnail\":\"https://img1.baidu.com/it/u=3426268058,1014861135&fm=253&fmt=auto&app=138&f=JPEG?w=190&h=118\",\"introImages\":[\"https://nimg.ws.126.net/?url=http%3A%2F%2Fdingyue.ws.126.net%2F2021%2F0916%2F2ff161bap00qzik7b00aad000t700inp.png&thumbnail=660x2147483647&quality=80&type=jpg\"],\"detailImages\":[\"https://nimg.ws.126.net/?url=http%3A%2F%2Fdingyue.ws.126.net%2F2021%2F0916%2F5527f996p00qzikdu00avd000th00inp.png&thumbnail=660x2147483647&quality=80&type=jpg\",\"https://nimg.ws.126.net/?url=http%3A%2F%2Fdingyue.ws.126.net%2F2021%2F0916%2Fbe0a3f04p00qziken00cvd000te00ikp.png&thumbnail=660x2147483647&quality=80&type=jpg\"]},\"desc\":\"\",\"remark\":\"\",\"tags\":[\"YYDS\",\"杨幂同款\"],\"specs\":[{\"specId\":1,\"specName\":\"温度\",\"rules\":[{\"ruleId\":1,\"ruleName\":\"常温\",\"price\":0},{\"ruleId\":2,\"ruleName\":\"加冰\",\"price\":2},{\"ruleId\":3,\"ruleName\":\"加热\",\"price\":3}]},{\"specId\":2,\"specName\":\"糖度\",\"rules\":[{\"ruleId\":4,\"ruleName\":\"无糖\",\"price\":0},{\"ruleId\":5,\"ruleName\":\"少糖\",\"price\":1},{\"ruleId\":6,\"ruleName\":\"多糖\",\"price\":2}]}],\"skus\":[{\"skuId\":1,\"state\":1,\"rules\":[{\"specId\":1,\"specName\":\"温度\",\"ruleId\":1,\"ruleName\":\"常温\",\"price\":0.00},{\"specId\":2,\"specName\":\"糖度\",\"ruleId\":3,\"ruleName\":\"无糖\",\"price\":0.00}]},{\"skuId\":1,\"state\":1,\"rules\":[{\"specId\":1,\"specName\":\"温度\",\"ruleId\":2,\"ruleName\":\"冰\",\"price\":2.00},{\"specId\":2,\"specName\":\"糖度\",\"ruleId\":3,\"ruleName\":\"无糖\",\"price\":0.00}]},{\"skuId\":1,\"state\":1,\"rules\":[{\"specId\":1,\"specName\":\"温度\",\"ruleId\":1,\"ruleName\":\"常温\",\"price\":0.00},{\"specId\":2,\"specName\":\"糖度\",\"ruleId\":3,\"ruleName\":\"加糖\",\"price\":2.00}]},{\"skuId\":1,\"state\":1,\"rules\":[{\"specId\":1,\"specName\":\"温度\",\"ruleId\":1,\"ruleName\":\"冰\",\"price\":2.00},{\"specId\":2,\"specName\":\"糖度\",\"ruleId\":3,\"ruleName\":\"加糖\",\"price\":4.00}]}]}", Goods.class);
        Goods g6 = objectMapper.readValue("{\"goodId\":100,\"name\":\"冰茶咖啡\",\"price\":29.9,\"discount\":19.9,\"pics\":{\"thumbnail\":\"https://img1.baidu.com/it/u=3426268058,1014861135&fm=253&fmt=auto&app=138&f=JPEG?w=190&h=118\",\"introImages\":[\"https://nimg.ws.126.net/?url=http%3A%2F%2Fdingyue.ws.126.net%2F2021%2F0916%2F2ff161bap00qzik7b00aad000t700inp.png&thumbnail=660x2147483647&quality=80&type=jpg\"],\"detailImages\":[\"https://nimg.ws.126.net/?url=http%3A%2F%2Fdingyue.ws.126.net%2F2021%2F0916%2F5527f996p00qzikdu00avd000th00inp.png&thumbnail=660x2147483647&quality=80&type=jpg\",\"https://nimg.ws.126.net/?url=http%3A%2F%2Fdingyue.ws.126.net%2F2021%2F0916%2Fbe0a3f04p00qziken00cvd000te00ikp.png&thumbnail=660x2147483647&quality=80&type=jpg\"]},\"desc\":\"\",\"remark\":\"\",\"tags\":[\"YYDS\",\"杨幂同款\"],\"specs\":[{\"specId\":1,\"specName\":\"温度\",\"rules\":[{\"ruleId\":1,\"ruleName\":\"常温\",\"price\":0},{\"ruleId\":2,\"ruleName\":\"加冰\",\"price\":2},{\"ruleId\":3,\"ruleName\":\"加热\",\"price\":3}]},{\"specId\":2,\"specName\":\"糖度\",\"rules\":[{\"ruleId\":4,\"ruleName\":\"无糖\",\"price\":0},{\"ruleId\":5,\"ruleName\":\"少糖\",\"price\":1},{\"ruleId\":6,\"ruleName\":\"多糖\",\"price\":2}]}],\"skus\":[{\"skuId\":1,\"state\":1,\"rules\":[{\"specId\":1,\"specName\":\"温度\",\"ruleId\":1,\"ruleName\":\"常温\",\"price\":0.00},{\"specId\":2,\"specName\":\"糖度\",\"ruleId\":3,\"ruleName\":\"无糖\",\"price\":0.00}]},{\"skuId\":1,\"state\":1,\"rules\":[{\"specId\":1,\"specName\":\"温度\",\"ruleId\":2,\"ruleName\":\"冰\",\"price\":2.00},{\"specId\":2,\"specName\":\"糖度\",\"ruleId\":3,\"ruleName\":\"无糖\",\"price\":0.00}]},{\"skuId\":1,\"state\":1,\"rules\":[{\"specId\":1,\"specName\":\"温度\",\"ruleId\":1,\"ruleName\":\"常温\",\"price\":0.00},{\"specId\":2,\"specName\":\"糖度\",\"ruleId\":3,\"ruleName\":\"加糖\",\"price\":2.00}]},{\"skuId\":1,\"state\":1,\"rules\":[{\"specId\":1,\"specName\":\"温度\",\"ruleId\":1,\"ruleName\":\"冰\",\"price\":2.00},{\"specId\":2,\"specName\":\"糖度\",\"ruleId\":3,\"ruleName\":\"加糖\",\"price\":4.00}]}]}", Goods.class);
        Goods g7 = objectMapper.readValue("{\"goodId\":100,\"name\":\"冰茶咖啡\",\"price\":29.9,\"discount\":19.9,\"pics\":{\"thumbnail\":\"https://img1.baidu.com/it/u=3426268058,1014861135&fm=253&fmt=auto&app=138&f=JPEG?w=190&h=118\",\"introImages\":[\"https://nimg.ws.126.net/?url=http%3A%2F%2Fdingyue.ws.126.net%2F2021%2F0916%2F2ff161bap00qzik7b00aad000t700inp.png&thumbnail=660x2147483647&quality=80&type=jpg\"],\"detailImages\":[\"https://nimg.ws.126.net/?url=http%3A%2F%2Fdingyue.ws.126.net%2F2021%2F0916%2F5527f996p00qzikdu00avd000th00inp.png&thumbnail=660x2147483647&quality=80&type=jpg\",\"https://nimg.ws.126.net/?url=http%3A%2F%2Fdingyue.ws.126.net%2F2021%2F0916%2Fbe0a3f04p00qziken00cvd000te00ikp.png&thumbnail=660x2147483647&quality=80&type=jpg\"]},\"desc\":\"\",\"remark\":\"\",\"tags\":[\"YYDS\",\"杨幂同款\"],\"specs\":[{\"specId\":1,\"specName\":\"温度\",\"rules\":[{\"ruleId\":1,\"ruleName\":\"常温\",\"price\":0},{\"ruleId\":2,\"ruleName\":\"加冰\",\"price\":2},{\"ruleId\":3,\"ruleName\":\"加热\",\"price\":3}]},{\"specId\":2,\"specName\":\"糖度\",\"rules\":[{\"ruleId\":4,\"ruleName\":\"无糖\",\"price\":0},{\"ruleId\":5,\"ruleName\":\"少糖\",\"price\":1},{\"ruleId\":6,\"ruleName\":\"多糖\",\"price\":2}]}],\"skus\":[{\"skuId\":1,\"state\":1,\"rules\":[{\"specId\":1,\"specName\":\"温度\",\"ruleId\":1,\"ruleName\":\"常温\",\"price\":0.00},{\"specId\":2,\"specName\":\"糖度\",\"ruleId\":3,\"ruleName\":\"无糖\",\"price\":0.00}]},{\"skuId\":1,\"state\":1,\"rules\":[{\"specId\":1,\"specName\":\"温度\",\"ruleId\":2,\"ruleName\":\"冰\",\"price\":2.00},{\"specId\":2,\"specName\":\"糖度\",\"ruleId\":3,\"ruleName\":\"无糖\",\"price\":0.00}]},{\"skuId\":1,\"state\":1,\"rules\":[{\"specId\":1,\"specName\":\"温度\",\"ruleId\":1,\"ruleName\":\"常温\",\"price\":0.00},{\"specId\":2,\"specName\":\"糖度\",\"ruleId\":3,\"ruleName\":\"加糖\",\"price\":2.00}]},{\"skuId\":1,\"state\":1,\"rules\":[{\"specId\":1,\"specName\":\"温度\",\"ruleId\":1,\"ruleName\":\"冰\",\"price\":2.00},{\"specId\":2,\"specName\":\"糖度\",\"ruleId\":3,\"ruleName\":\"加糖\",\"price\":4.00}]}]}", Goods.class);
        Goods g8 = objectMapper.readValue("{\"goodId\":100,\"name\":\"冰茶咖啡\",\"price\":29.9,\"discount\":19.9,\"pics\":{\"thumbnail\":\"https://img1.baidu.com/it/u=3426268058,1014861135&fm=253&fmt=auto&app=138&f=JPEG?w=190&h=118\",\"introImages\":[\"https://nimg.ws.126.net/?url=http%3A%2F%2Fdingyue.ws.126.net%2F2021%2F0916%2F2ff161bap00qzik7b00aad000t700inp.png&thumbnail=660x2147483647&quality=80&type=jpg\"],\"detailImages\":[\"https://nimg.ws.126.net/?url=http%3A%2F%2Fdingyue.ws.126.net%2F2021%2F0916%2F5527f996p00qzikdu00avd000th00inp.png&thumbnail=660x2147483647&quality=80&type=jpg\",\"https://nimg.ws.126.net/?url=http%3A%2F%2Fdingyue.ws.126.net%2F2021%2F0916%2Fbe0a3f04p00qziken00cvd000te00ikp.png&thumbnail=660x2147483647&quality=80&type=jpg\"]},\"desc\":\"\",\"remark\":\"\",\"tags\":[\"YYDS\",\"杨幂同款\"],\"specs\":[{\"specId\":1,\"specName\":\"温度\",\"rules\":[{\"ruleId\":1,\"ruleName\":\"常温\",\"price\":0},{\"ruleId\":2,\"ruleName\":\"加冰\",\"price\":2},{\"ruleId\":3,\"ruleName\":\"加热\",\"price\":3}]},{\"specId\":2,\"specName\":\"糖度\",\"rules\":[{\"ruleId\":4,\"ruleName\":\"无糖\",\"price\":0},{\"ruleId\":5,\"ruleName\":\"少糖\",\"price\":1},{\"ruleId\":6,\"ruleName\":\"多糖\",\"price\":2}]}],\"skus\":[{\"skuId\":1,\"state\":1,\"rules\":[{\"specId\":1,\"specName\":\"温度\",\"ruleId\":1,\"ruleName\":\"常温\",\"price\":0.00},{\"specId\":2,\"specName\":\"糖度\",\"ruleId\":3,\"ruleName\":\"无糖\",\"price\":0.00}]},{\"skuId\":1,\"state\":1,\"rules\":[{\"specId\":1,\"specName\":\"温度\",\"ruleId\":2,\"ruleName\":\"冰\",\"price\":2.00},{\"specId\":2,\"specName\":\"糖度\",\"ruleId\":3,\"ruleName\":\"无糖\",\"price\":0.00}]},{\"skuId\":1,\"state\":1,\"rules\":[{\"specId\":1,\"specName\":\"温度\",\"ruleId\":1,\"ruleName\":\"常温\",\"price\":0.00},{\"specId\":2,\"specName\":\"糖度\",\"ruleId\":3,\"ruleName\":\"加糖\",\"price\":2.00}]},{\"skuId\":1,\"state\":1,\"rules\":[{\"specId\":1,\"specName\":\"温度\",\"ruleId\":1,\"ruleName\":\"冰\",\"price\":2.00},{\"specId\":2,\"specName\":\"糖度\",\"ruleId\":3,\"ruleName\":\"加糖\",\"price\":4.00}]}]}", Goods.class);
        Goods g9 = objectMapper.readValue("{\"goodId\":100,\"name\":\"冰茶咖啡\",\"price\":29.9,\"discount\":19.9,\"pics\":{\"thumbnail\":\"https://img1.baidu.com/it/u=3426268058,1014861135&fm=253&fmt=auto&app=138&f=JPEG?w=190&h=118\",\"introImages\":[\"https://nimg.ws.126.net/?url=http%3A%2F%2Fdingyue.ws.126.net%2F2021%2F0916%2F2ff161bap00qzik7b00aad000t700inp.png&thumbnail=660x2147483647&quality=80&type=jpg\"],\"detailImages\":[\"https://nimg.ws.126.net/?url=http%3A%2F%2Fdingyue.ws.126.net%2F2021%2F0916%2F5527f996p00qzikdu00avd000th00inp.png&thumbnail=660x2147483647&quality=80&type=jpg\",\"https://nimg.ws.126.net/?url=http%3A%2F%2Fdingyue.ws.126.net%2F2021%2F0916%2Fbe0a3f04p00qziken00cvd000te00ikp.png&thumbnail=660x2147483647&quality=80&type=jpg\"]},\"desc\":\"\",\"remark\":\"\",\"tags\":[\"YYDS\",\"杨幂同款\"],\"specs\":[{\"specId\":1,\"specName\":\"温度\",\"rules\":[{\"ruleId\":1,\"ruleName\":\"常温\",\"price\":0},{\"ruleId\":2,\"ruleName\":\"加冰\",\"price\":2},{\"ruleId\":3,\"ruleName\":\"加热\",\"price\":3}]},{\"specId\":2,\"specName\":\"糖度\",\"rules\":[{\"ruleId\":4,\"ruleName\":\"无糖\",\"price\":0},{\"ruleId\":5,\"ruleName\":\"少糖\",\"price\":1},{\"ruleId\":6,\"ruleName\":\"多糖\",\"price\":2}]}],\"skus\":[{\"skuId\":1,\"state\":1,\"rules\":[{\"specId\":1,\"specName\":\"温度\",\"ruleId\":1,\"ruleName\":\"常温\",\"price\":0.00},{\"specId\":2,\"specName\":\"糖度\",\"ruleId\":3,\"ruleName\":\"无糖\",\"price\":0.00}]},{\"skuId\":1,\"state\":1,\"rules\":[{\"specId\":1,\"specName\":\"温度\",\"ruleId\":2,\"ruleName\":\"冰\",\"price\":2.00},{\"specId\":2,\"specName\":\"糖度\",\"ruleId\":3,\"ruleName\":\"无糖\",\"price\":0.00}]},{\"skuId\":1,\"state\":1,\"rules\":[{\"specId\":1,\"specName\":\"温度\",\"ruleId\":1,\"ruleName\":\"常温\",\"price\":0.00},{\"specId\":2,\"specName\":\"糖度\",\"ruleId\":3,\"ruleName\":\"加糖\",\"price\":2.00}]},{\"skuId\":1,\"state\":1,\"rules\":[{\"specId\":1,\"specName\":\"温度\",\"ruleId\":1,\"ruleName\":\"冰\",\"price\":2.00},{\"specId\":2,\"specName\":\"糖度\",\"ruleId\":3,\"ruleName\":\"加糖\",\"price\":4.00}]}]}", Goods.class);
        Goods g10 = objectMapper.readValue("{\"goodId\":100,\"name\":\"冰茶咖啡\",\"price\":29.9,\"discount\":19.9,\"pics\":{\"thumbnail\":\"https://img1.baidu.com/it/u=3426268058,1014861135&fm=253&fmt=auto&app=138&f=JPEG?w=190&h=118\",\"introImages\":[\"https://nimg.ws.126.net/?url=http%3A%2F%2Fdingyue.ws.126.net%2F2021%2F0916%2F2ff161bap00qzik7b00aad000t700inp.png&thumbnail=660x2147483647&quality=80&type=jpg\"],\"detailImages\":[\"https://nimg.ws.126.net/?url=http%3A%2F%2Fdingyue.ws.126.net%2F2021%2F0916%2F5527f996p00qzikdu00avd000th00inp.png&thumbnail=660x2147483647&quality=80&type=jpg\",\"https://nimg.ws.126.net/?url=http%3A%2F%2Fdingyue.ws.126.net%2F2021%2F0916%2Fbe0a3f04p00qziken00cvd000te00ikp.png&thumbnail=660x2147483647&quality=80&type=jpg\"]},\"desc\":\"\",\"remark\":\"\",\"tags\":[\"YYDS\",\"杨幂同款\"],\"specs\":[{\"specId\":1,\"specName\":\"温度\",\"rules\":[{\"ruleId\":1,\"ruleName\":\"常温\",\"price\":0},{\"ruleId\":2,\"ruleName\":\"加冰\",\"price\":2},{\"ruleId\":3,\"ruleName\":\"加热\",\"price\":3}]},{\"specId\":2,\"specName\":\"糖度\",\"rules\":[{\"ruleId\":4,\"ruleName\":\"无糖\",\"price\":0},{\"ruleId\":5,\"ruleName\":\"少糖\",\"price\":1},{\"ruleId\":6,\"ruleName\":\"多糖\",\"price\":2}]}],\"skus\":[{\"skuId\":1,\"state\":1,\"rules\":[{\"specId\":1,\"specName\":\"温度\",\"ruleId\":1,\"ruleName\":\"常温\",\"price\":0.00},{\"specId\":2,\"specName\":\"糖度\",\"ruleId\":3,\"ruleName\":\"无糖\",\"price\":0.00}]},{\"skuId\":1,\"state\":1,\"rules\":[{\"specId\":1,\"specName\":\"温度\",\"ruleId\":2,\"ruleName\":\"冰\",\"price\":2.00},{\"specId\":2,\"specName\":\"糖度\",\"ruleId\":3,\"ruleName\":\"无糖\",\"price\":0.00}]},{\"skuId\":1,\"state\":1,\"rules\":[{\"specId\":1,\"specName\":\"温度\",\"ruleId\":1,\"ruleName\":\"常温\",\"price\":0.00},{\"specId\":2,\"specName\":\"糖度\",\"ruleId\":3,\"ruleName\":\"加糖\",\"price\":2.00}]},{\"skuId\":1,\"state\":1,\"rules\":[{\"specId\":1,\"specName\":\"温度\",\"ruleId\":1,\"ruleName\":\"冰\",\"price\":2.00},{\"specId\":2,\"specName\":\"糖度\",\"ruleId\":3,\"ruleName\":\"加糖\",\"price\":4.00}]}]}", Goods.class);
        Goods g11 = objectMapper.readValue("{\"goodId\":100,\"name\":\"冰茶咖啡\",\"price\":29.9,\"discount\":19.9,\"pics\":{\"thumbnail\":\"https://img1.baidu.com/it/u=3426268058,1014861135&fm=253&fmt=auto&app=138&f=JPEG?w=190&h=118\",\"introImages\":[\"https://nimg.ws.126.net/?url=http%3A%2F%2Fdingyue.ws.126.net%2F2021%2F0916%2F2ff161bap00qzik7b00aad000t700inp.png&thumbnail=660x2147483647&quality=80&type=jpg\"],\"detailImages\":[\"https://nimg.ws.126.net/?url=http%3A%2F%2Fdingyue.ws.126.net%2F2021%2F0916%2F5527f996p00qzikdu00avd000th00inp.png&thumbnail=660x2147483647&quality=80&type=jpg\",\"https://nimg.ws.126.net/?url=http%3A%2F%2Fdingyue.ws.126.net%2F2021%2F0916%2Fbe0a3f04p00qziken00cvd000te00ikp.png&thumbnail=660x2147483647&quality=80&type=jpg\"]},\"desc\":\"\",\"remark\":\"\",\"tags\":[\"YYDS\",\"杨幂同款\"],\"specs\":[{\"specId\":1,\"specName\":\"温度\",\"rules\":[{\"ruleId\":1,\"ruleName\":\"常温\",\"price\":0},{\"ruleId\":2,\"ruleName\":\"加冰\",\"price\":2},{\"ruleId\":3,\"ruleName\":\"加热\",\"price\":3}]},{\"specId\":2,\"specName\":\"糖度\",\"rules\":[{\"ruleId\":4,\"ruleName\":\"无糖\",\"price\":0},{\"ruleId\":5,\"ruleName\":\"少糖\",\"price\":1},{\"ruleId\":6,\"ruleName\":\"多糖\",\"price\":2}]}],\"skus\":[{\"skuId\":1,\"state\":1,\"rules\":[{\"specId\":1,\"specName\":\"温度\",\"ruleId\":1,\"ruleName\":\"常温\",\"price\":0.00},{\"specId\":2,\"specName\":\"糖度\",\"ruleId\":3,\"ruleName\":\"无糖\",\"price\":0.00}]},{\"skuId\":1,\"state\":1,\"rules\":[{\"specId\":1,\"specName\":\"温度\",\"ruleId\":2,\"ruleName\":\"冰\",\"price\":2.00},{\"specId\":2,\"specName\":\"糖度\",\"ruleId\":3,\"ruleName\":\"无糖\",\"price\":0.00}]},{\"skuId\":1,\"state\":1,\"rules\":[{\"specId\":1,\"specName\":\"温度\",\"ruleId\":1,\"ruleName\":\"常温\",\"price\":0.00},{\"specId\":2,\"specName\":\"糖度\",\"ruleId\":3,\"ruleName\":\"加糖\",\"price\":2.00}]},{\"skuId\":1,\"state\":1,\"rules\":[{\"specId\":1,\"specName\":\"温度\",\"ruleId\":1,\"ruleName\":\"冰\",\"price\":2.00},{\"specId\":2,\"specName\":\"糖度\",\"ruleId\":3,\"ruleName\":\"加糖\",\"price\":4.00}]}]}", Goods.class);
        Goods g12 = objectMapper.readValue("{\"goodId\":100,\"name\":\"冰茶咖啡\",\"price\":29.9,\"discount\":19.9,\"pics\":{\"thumbnail\":\"https://img1.baidu.com/it/u=3426268058,1014861135&fm=253&fmt=auto&app=138&f=JPEG?w=190&h=118\",\"introImages\":[\"https://nimg.ws.126.net/?url=http%3A%2F%2Fdingyue.ws.126.net%2F2021%2F0916%2F2ff161bap00qzik7b00aad000t700inp.png&thumbnail=660x2147483647&quality=80&type=jpg\"],\"detailImages\":[\"https://nimg.ws.126.net/?url=http%3A%2F%2Fdingyue.ws.126.net%2F2021%2F0916%2F5527f996p00qzikdu00avd000th00inp.png&thumbnail=660x2147483647&quality=80&type=jpg\",\"https://nimg.ws.126.net/?url=http%3A%2F%2Fdingyue.ws.126.net%2F2021%2F0916%2Fbe0a3f04p00qziken00cvd000te00ikp.png&thumbnail=660x2147483647&quality=80&type=jpg\"]},\"desc\":\"\",\"remark\":\"\",\"tags\":[\"YYDS\",\"杨幂同款\"],\"specs\":[{\"specId\":1,\"specName\":\"温度\",\"rules\":[{\"ruleId\":1,\"ruleName\":\"常温\",\"price\":0},{\"ruleId\":2,\"ruleName\":\"加冰\",\"price\":2},{\"ruleId\":3,\"ruleName\":\"加热\",\"price\":3}]},{\"specId\":2,\"specName\":\"糖度\",\"rules\":[{\"ruleId\":4,\"ruleName\":\"无糖\",\"price\":0},{\"ruleId\":5,\"ruleName\":\"少糖\",\"price\":1},{\"ruleId\":6,\"ruleName\":\"多糖\",\"price\":2}]}],\"skus\":[{\"skuId\":1,\"state\":1,\"rules\":[{\"specId\":1,\"specName\":\"温度\",\"ruleId\":1,\"ruleName\":\"常温\",\"price\":0.00},{\"specId\":2,\"specName\":\"糖度\",\"ruleId\":3,\"ruleName\":\"无糖\",\"price\":0.00}]},{\"skuId\":1,\"state\":1,\"rules\":[{\"specId\":1,\"specName\":\"温度\",\"ruleId\":2,\"ruleName\":\"冰\",\"price\":2.00},{\"specId\":2,\"specName\":\"糖度\",\"ruleId\":3,\"ruleName\":\"无糖\",\"price\":0.00}]},{\"skuId\":1,\"state\":1,\"rules\":[{\"specId\":1,\"specName\":\"温度\",\"ruleId\":1,\"ruleName\":\"常温\",\"price\":0.00},{\"specId\":2,\"specName\":\"糖度\",\"ruleId\":3,\"ruleName\":\"加糖\",\"price\":2.00}]},{\"skuId\":1,\"state\":1,\"rules\":[{\"specId\":1,\"specName\":\"温度\",\"ruleId\":1,\"ruleName\":\"冰\",\"price\":2.00},{\"specId\":2,\"specName\":\"糖度\",\"ruleId\":3,\"ruleName\":\"加糖\",\"price\":4.00}]}]}", Goods.class);
        Goods g13 = objectMapper.readValue("{\"goodId\":100,\"name\":\"冰茶咖啡\",\"price\":29.9,\"discount\":19.9,\"pics\":{\"thumbnail\":\"https://img1.baidu.com/it/u=3426268058,1014861135&fm=253&fmt=auto&app=138&f=JPEG?w=190&h=118\",\"introImages\":[\"https://nimg.ws.126.net/?url=http%3A%2F%2Fdingyue.ws.126.net%2F2021%2F0916%2F2ff161bap00qzik7b00aad000t700inp.png&thumbnail=660x2147483647&quality=80&type=jpg\"],\"detailImages\":[\"https://nimg.ws.126.net/?url=http%3A%2F%2Fdingyue.ws.126.net%2F2021%2F0916%2F5527f996p00qzikdu00avd000th00inp.png&thumbnail=660x2147483647&quality=80&type=jpg\",\"https://nimg.ws.126.net/?url=http%3A%2F%2Fdingyue.ws.126.net%2F2021%2F0916%2Fbe0a3f04p00qziken00cvd000te00ikp.png&thumbnail=660x2147483647&quality=80&type=jpg\"]},\"desc\":\"\",\"remark\":\"\",\"tags\":[\"YYDS\",\"杨幂同款\"],\"specs\":[{\"specId\":1,\"specName\":\"温度\",\"rules\":[{\"ruleId\":1,\"ruleName\":\"常温\",\"price\":0},{\"ruleId\":2,\"ruleName\":\"加冰\",\"price\":2},{\"ruleId\":3,\"ruleName\":\"加热\",\"price\":3}]},{\"specId\":2,\"specName\":\"糖度\",\"rules\":[{\"ruleId\":4,\"ruleName\":\"无糖\",\"price\":0},{\"ruleId\":5,\"ruleName\":\"少糖\",\"price\":1},{\"ruleId\":6,\"ruleName\":\"多糖\",\"price\":2}]}],\"skus\":[{\"skuId\":1,\"state\":1,\"rules\":[{\"specId\":1,\"specName\":\"温度\",\"ruleId\":1,\"ruleName\":\"常温\",\"price\":0.00},{\"specId\":2,\"specName\":\"糖度\",\"ruleId\":3,\"ruleName\":\"无糖\",\"price\":0.00}]},{\"skuId\":1,\"state\":1,\"rules\":[{\"specId\":1,\"specName\":\"温度\",\"ruleId\":2,\"ruleName\":\"冰\",\"price\":2.00},{\"specId\":2,\"specName\":\"糖度\",\"ruleId\":3,\"ruleName\":\"无糖\",\"price\":0.00}]},{\"skuId\":1,\"state\":1,\"rules\":[{\"specId\":1,\"specName\":\"温度\",\"ruleId\":1,\"ruleName\":\"常温\",\"price\":0.00},{\"specId\":2,\"specName\":\"糖度\",\"ruleId\":3,\"ruleName\":\"加糖\",\"price\":2.00}]},{\"skuId\":1,\"state\":1,\"rules\":[{\"specId\":1,\"specName\":\"温度\",\"ruleId\":1,\"ruleName\":\"冰\",\"price\":2.00},{\"specId\":2,\"specName\":\"糖度\",\"ruleId\":3,\"ruleName\":\"加糖\",\"price\":4.00}]}]}", Goods.class);
        Goods g14 = objectMapper.readValue("{\"goodId\":100,\"name\":\"冰茶咖啡\",\"price\":29.9,\"discount\":19.9,\"pics\":{\"thumbnail\":\"https://img1.baidu.com/it/u=3426268058,1014861135&fm=253&fmt=auto&app=138&f=JPEG?w=190&h=118\",\"introImages\":[\"https://nimg.ws.126.net/?url=http%3A%2F%2Fdingyue.ws.126.net%2F2021%2F0916%2F2ff161bap00qzik7b00aad000t700inp.png&thumbnail=660x2147483647&quality=80&type=jpg\"],\"detailImages\":[\"https://nimg.ws.126.net/?url=http%3A%2F%2Fdingyue.ws.126.net%2F2021%2F0916%2F5527f996p00qzikdu00avd000th00inp.png&thumbnail=660x2147483647&quality=80&type=jpg\",\"https://nimg.ws.126.net/?url=http%3A%2F%2Fdingyue.ws.126.net%2F2021%2F0916%2Fbe0a3f04p00qziken00cvd000te00ikp.png&thumbnail=660x2147483647&quality=80&type=jpg\"]},\"desc\":\"\",\"remark\":\"\",\"tags\":[\"YYDS\",\"杨幂同款\"],\"specs\":[{\"specId\":1,\"specName\":\"温度\",\"rules\":[{\"ruleId\":1,\"ruleName\":\"常温\",\"price\":0},{\"ruleId\":2,\"ruleName\":\"加冰\",\"price\":2},{\"ruleId\":3,\"ruleName\":\"加热\",\"price\":3}]},{\"specId\":2,\"specName\":\"糖度\",\"rules\":[{\"ruleId\":4,\"ruleName\":\"无糖\",\"price\":0},{\"ruleId\":5,\"ruleName\":\"少糖\",\"price\":1},{\"ruleId\":6,\"ruleName\":\"多糖\",\"price\":2}]}],\"skus\":[{\"skuId\":1,\"state\":1,\"rules\":[{\"specId\":1,\"specName\":\"温度\",\"ruleId\":1,\"ruleName\":\"常温\",\"price\":0.00},{\"specId\":2,\"specName\":\"糖度\",\"ruleId\":3,\"ruleName\":\"无糖\",\"price\":0.00}]},{\"skuId\":1,\"state\":1,\"rules\":[{\"specId\":1,\"specName\":\"温度\",\"ruleId\":2,\"ruleName\":\"冰\",\"price\":2.00},{\"specId\":2,\"specName\":\"糖度\",\"ruleId\":3,\"ruleName\":\"无糖\",\"price\":0.00}]},{\"skuId\":1,\"state\":1,\"rules\":[{\"specId\":1,\"specName\":\"温度\",\"ruleId\":1,\"ruleName\":\"常温\",\"price\":0.00},{\"specId\":2,\"specName\":\"糖度\",\"ruleId\":3,\"ruleName\":\"加糖\",\"price\":2.00}]},{\"skuId\":1,\"state\":1,\"rules\":[{\"specId\":1,\"specName\":\"温度\",\"ruleId\":1,\"ruleName\":\"冰\",\"price\":2.00},{\"specId\":2,\"specName\":\"糖度\",\"ruleId\":3,\"ruleName\":\"加糖\",\"price\":4.00}]}]}", Goods.class);
        Goods g15 = objectMapper.readValue("{\"goodId\":100,\"name\":\"冰茶咖啡\",\"price\":29.9,\"discount\":19.9,\"pics\":{\"thumbnail\":\"https://img1.baidu.com/it/u=3426268058,1014861135&fm=253&fmt=auto&app=138&f=JPEG?w=190&h=118\",\"introImages\":[\"https://nimg.ws.126.net/?url=http%3A%2F%2Fdingyue.ws.126.net%2F2021%2F0916%2F2ff161bap00qzik7b00aad000t700inp.png&thumbnail=660x2147483647&quality=80&type=jpg\"],\"detailImages\":[\"https://nimg.ws.126.net/?url=http%3A%2F%2Fdingyue.ws.126.net%2F2021%2F0916%2F5527f996p00qzikdu00avd000th00inp.png&thumbnail=660x2147483647&quality=80&type=jpg\",\"https://nimg.ws.126.net/?url=http%3A%2F%2Fdingyue.ws.126.net%2F2021%2F0916%2Fbe0a3f04p00qziken00cvd000te00ikp.png&thumbnail=660x2147483647&quality=80&type=jpg\"]},\"desc\":\"\",\"remark\":\"\",\"tags\":[\"YYDS\",\"杨幂同款\"],\"specs\":[{\"specId\":1,\"specName\":\"温度\",\"rules\":[{\"ruleId\":1,\"ruleName\":\"常温\",\"price\":0},{\"ruleId\":2,\"ruleName\":\"加冰\",\"price\":2},{\"ruleId\":3,\"ruleName\":\"加热\",\"price\":3}]},{\"specId\":2,\"specName\":\"糖度\",\"rules\":[{\"ruleId\":4,\"ruleName\":\"无糖\",\"price\":0},{\"ruleId\":5,\"ruleName\":\"少糖\",\"price\":1},{\"ruleId\":6,\"ruleName\":\"多糖\",\"price\":2}]}],\"skus\":[{\"skuId\":1,\"state\":1,\"rules\":[{\"specId\":1,\"specName\":\"温度\",\"ruleId\":1,\"ruleName\":\"常温\",\"price\":0.00},{\"specId\":2,\"specName\":\"糖度\",\"ruleId\":3,\"ruleName\":\"无糖\",\"price\":0.00}]},{\"skuId\":1,\"state\":1,\"rules\":[{\"specId\":1,\"specName\":\"温度\",\"ruleId\":2,\"ruleName\":\"冰\",\"price\":2.00},{\"specId\":2,\"specName\":\"糖度\",\"ruleId\":3,\"ruleName\":\"无糖\",\"price\":0.00}]},{\"skuId\":1,\"state\":1,\"rules\":[{\"specId\":1,\"specName\":\"温度\",\"ruleId\":1,\"ruleName\":\"常温\",\"price\":0.00},{\"specId\":2,\"specName\":\"糖度\",\"ruleId\":3,\"ruleName\":\"加糖\",\"price\":2.00}]},{\"skuId\":1,\"state\":1,\"rules\":[{\"specId\":1,\"specName\":\"温度\",\"ruleId\":1,\"ruleName\":\"冰\",\"price\":2.00},{\"specId\":2,\"specName\":\"糖度\",\"ruleId\":3,\"ruleName\":\"加糖\",\"price\":4.00}]}]}", Goods.class);
        Goods g16 = objectMapper.readValue("{\"goodId\":100,\"name\":\"冰茶咖啡\",\"price\":29.9,\"discount\":19.9,\"pics\":{\"thumbnail\":\"https://img1.baidu.com/it/u=3426268058,1014861135&fm=253&fmt=auto&app=138&f=JPEG?w=190&h=118\",\"introImages\":[\"https://nimg.ws.126.net/?url=http%3A%2F%2Fdingyue.ws.126.net%2F2021%2F0916%2F2ff161bap00qzik7b00aad000t700inp.png&thumbnail=660x2147483647&quality=80&type=jpg\"],\"detailImages\":[\"https://nimg.ws.126.net/?url=http%3A%2F%2Fdingyue.ws.126.net%2F2021%2F0916%2F5527f996p00qzikdu00avd000th00inp.png&thumbnail=660x2147483647&quality=80&type=jpg\",\"https://nimg.ws.126.net/?url=http%3A%2F%2Fdingyue.ws.126.net%2F2021%2F0916%2Fbe0a3f04p00qziken00cvd000te00ikp.png&thumbnail=660x2147483647&quality=80&type=jpg\"]},\"desc\":\"\",\"remark\":\"\",\"tags\":[\"YYDS\",\"杨幂同款\"],\"specs\":[{\"specId\":1,\"specName\":\"温度\",\"rules\":[{\"ruleId\":1,\"ruleName\":\"常温\",\"price\":0},{\"ruleId\":2,\"ruleName\":\"加冰\",\"price\":2},{\"ruleId\":3,\"ruleName\":\"加热\",\"price\":3}]},{\"specId\":2,\"specName\":\"糖度\",\"rules\":[{\"ruleId\":4,\"ruleName\":\"无糖\",\"price\":0},{\"ruleId\":5,\"ruleName\":\"少糖\",\"price\":1},{\"ruleId\":6,\"ruleName\":\"多糖\",\"price\":2}]}],\"skus\":[{\"skuId\":1,\"state\":1,\"rules\":[{\"specId\":1,\"specName\":\"温度\",\"ruleId\":1,\"ruleName\":\"常温\",\"price\":0.00},{\"specId\":2,\"specName\":\"糖度\",\"ruleId\":3,\"ruleName\":\"无糖\",\"price\":0.00}]},{\"skuId\":1,\"state\":1,\"rules\":[{\"specId\":1,\"specName\":\"温度\",\"ruleId\":2,\"ruleName\":\"冰\",\"price\":2.00},{\"specId\":2,\"specName\":\"糖度\",\"ruleId\":3,\"ruleName\":\"无糖\",\"price\":0.00}]},{\"skuId\":1,\"state\":1,\"rules\":[{\"specId\":1,\"specName\":\"温度\",\"ruleId\":1,\"ruleName\":\"常温\",\"price\":0.00},{\"specId\":2,\"specName\":\"糖度\",\"ruleId\":3,\"ruleName\":\"加糖\",\"price\":2.00}]},{\"skuId\":1,\"state\":1,\"rules\":[{\"specId\":1,\"specName\":\"温度\",\"ruleId\":1,\"ruleName\":\"冰\",\"price\":2.00},{\"specId\":2,\"specName\":\"糖度\",\"ruleId\":3,\"ruleName\":\"加糖\",\"price\":4.00}]}]}", Goods.class);
        Goods g17 = objectMapper.readValue("{\"goodId\":100,\"name\":\"冰茶咖啡\",\"price\":29.9,\"discount\":19.9,\"pics\":{\"thumbnail\":\"https://img1.baidu.com/it/u=3426268058,1014861135&fm=253&fmt=auto&app=138&f=JPEG?w=190&h=118\",\"introImages\":[\"https://nimg.ws.126.net/?url=http%3A%2F%2Fdingyue.ws.126.net%2F2021%2F0916%2F2ff161bap00qzik7b00aad000t700inp.png&thumbnail=660x2147483647&quality=80&type=jpg\"],\"detailImages\":[\"https://nimg.ws.126.net/?url=http%3A%2F%2Fdingyue.ws.126.net%2F2021%2F0916%2F5527f996p00qzikdu00avd000th00inp.png&thumbnail=660x2147483647&quality=80&type=jpg\",\"https://nimg.ws.126.net/?url=http%3A%2F%2Fdingyue.ws.126.net%2F2021%2F0916%2Fbe0a3f04p00qziken00cvd000te00ikp.png&thumbnail=660x2147483647&quality=80&type=jpg\"]},\"desc\":\"\",\"remark\":\"\",\"tags\":[\"YYDS\",\"杨幂同款\"],\"specs\":[{\"specId\":1,\"specName\":\"温度\",\"rules\":[{\"ruleId\":1,\"ruleName\":\"常温\",\"price\":0},{\"ruleId\":2,\"ruleName\":\"加冰\",\"price\":2},{\"ruleId\":3,\"ruleName\":\"加热\",\"price\":3}]},{\"specId\":2,\"specName\":\"糖度\",\"rules\":[{\"ruleId\":4,\"ruleName\":\"无糖\",\"price\":0},{\"ruleId\":5,\"ruleName\":\"少糖\",\"price\":1},{\"ruleId\":6,\"ruleName\":\"多糖\",\"price\":2}]}],\"skus\":[{\"skuId\":1,\"state\":1,\"rules\":[{\"specId\":1,\"specName\":\"温度\",\"ruleId\":1,\"ruleName\":\"常温\",\"price\":0.00},{\"specId\":2,\"specName\":\"糖度\",\"ruleId\":3,\"ruleName\":\"无糖\",\"price\":0.00}]},{\"skuId\":1,\"state\":1,\"rules\":[{\"specId\":1,\"specName\":\"温度\",\"ruleId\":2,\"ruleName\":\"冰\",\"price\":2.00},{\"specId\":2,\"specName\":\"糖度\",\"ruleId\":3,\"ruleName\":\"无糖\",\"price\":0.00}]},{\"skuId\":1,\"state\":1,\"rules\":[{\"specId\":1,\"specName\":\"温度\",\"ruleId\":1,\"ruleName\":\"常温\",\"price\":0.00},{\"specId\":2,\"specName\":\"糖度\",\"ruleId\":3,\"ruleName\":\"加糖\",\"price\":2.00}]},{\"skuId\":1,\"state\":1,\"rules\":[{\"specId\":1,\"specName\":\"温度\",\"ruleId\":1,\"ruleName\":\"冰\",\"price\":2.00},{\"specId\":2,\"specName\":\"糖度\",\"ruleId\":3,\"ruleName\":\"加糖\",\"price\":4.00}]}]}", Goods.class);
        Goods g18 = objectMapper.readValue("{\"goodId\":100,\"name\":\"冰茶咖啡\",\"price\":29.9,\"discount\":19.9,\"pics\":{\"thumbnail\":\"https://img1.baidu.com/it/u=3426268058,1014861135&fm=253&fmt=auto&app=138&f=JPEG?w=190&h=118\",\"introImages\":[\"https://nimg.ws.126.net/?url=http%3A%2F%2Fdingyue.ws.126.net%2F2021%2F0916%2F2ff161bap00qzik7b00aad000t700inp.png&thumbnail=660x2147483647&quality=80&type=jpg\"],\"detailImages\":[\"https://nimg.ws.126.net/?url=http%3A%2F%2Fdingyue.ws.126.net%2F2021%2F0916%2F5527f996p00qzikdu00avd000th00inp.png&thumbnail=660x2147483647&quality=80&type=jpg\",\"https://nimg.ws.126.net/?url=http%3A%2F%2Fdingyue.ws.126.net%2F2021%2F0916%2Fbe0a3f04p00qziken00cvd000te00ikp.png&thumbnail=660x2147483647&quality=80&type=jpg\"]},\"desc\":\"\",\"remark\":\"\",\"tags\":[\"YYDS\",\"杨幂同款\"],\"specs\":[{\"specId\":1,\"specName\":\"温度\",\"rules\":[{\"ruleId\":1,\"ruleName\":\"常温\",\"price\":0},{\"ruleId\":2,\"ruleName\":\"加冰\",\"price\":2},{\"ruleId\":3,\"ruleName\":\"加热\",\"price\":3}]},{\"specId\":2,\"specName\":\"糖度\",\"rules\":[{\"ruleId\":4,\"ruleName\":\"无糖\",\"price\":0},{\"ruleId\":5,\"ruleName\":\"少糖\",\"price\":1},{\"ruleId\":6,\"ruleName\":\"多糖\",\"price\":2}]}],\"skus\":[{\"skuId\":1,\"state\":1,\"rules\":[{\"specId\":1,\"specName\":\"温度\",\"ruleId\":1,\"ruleName\":\"常温\",\"price\":0.00},{\"specId\":2,\"specName\":\"糖度\",\"ruleId\":3,\"ruleName\":\"无糖\",\"price\":0.00}]},{\"skuId\":1,\"state\":1,\"rules\":[{\"specId\":1,\"specName\":\"温度\",\"ruleId\":2,\"ruleName\":\"冰\",\"price\":2.00},{\"specId\":2,\"specName\":\"糖度\",\"ruleId\":3,\"ruleName\":\"无糖\",\"price\":0.00}]},{\"skuId\":1,\"state\":1,\"rules\":[{\"specId\":1,\"specName\":\"温度\",\"ruleId\":1,\"ruleName\":\"常温\",\"price\":0.00},{\"specId\":2,\"specName\":\"糖度\",\"ruleId\":3,\"ruleName\":\"加糖\",\"price\":2.00}]},{\"skuId\":1,\"state\":1,\"rules\":[{\"specId\":1,\"specName\":\"温度\",\"ruleId\":1,\"ruleName\":\"冰\",\"price\":2.00},{\"specId\":2,\"specName\":\"糖度\",\"ruleId\":3,\"ruleName\":\"加糖\",\"price\":4.00}]}]}", Goods.class);
        Goods g19 = objectMapper.readValue("{\"goodId\":100,\"name\":\"冰茶咖啡\",\"price\":29.9,\"discount\":19.9,\"pics\":{\"thumbnail\":\"https://img1.baidu.com/it/u=3426268058,1014861135&fm=253&fmt=auto&app=138&f=JPEG?w=190&h=118\",\"introImages\":[\"https://nimg.ws.126.net/?url=http%3A%2F%2Fdingyue.ws.126.net%2F2021%2F0916%2F2ff161bap00qzik7b00aad000t700inp.png&thumbnail=660x2147483647&quality=80&type=jpg\"],\"detailImages\":[\"https://nimg.ws.126.net/?url=http%3A%2F%2Fdingyue.ws.126.net%2F2021%2F0916%2F5527f996p00qzikdu00avd000th00inp.png&thumbnail=660x2147483647&quality=80&type=jpg\",\"https://nimg.ws.126.net/?url=http%3A%2F%2Fdingyue.ws.126.net%2F2021%2F0916%2Fbe0a3f04p00qziken00cvd000te00ikp.png&thumbnail=660x2147483647&quality=80&type=jpg\"]},\"desc\":\"\",\"remark\":\"\",\"tags\":[\"YYDS\",\"杨幂同款\"],\"specs\":[{\"specId\":1,\"specName\":\"温度\",\"rules\":[{\"ruleId\":1,\"ruleName\":\"常温\",\"price\":0},{\"ruleId\":2,\"ruleName\":\"加冰\",\"price\":2},{\"ruleId\":3,\"ruleName\":\"加热\",\"price\":3}]},{\"specId\":2,\"specName\":\"糖度\",\"rules\":[{\"ruleId\":4,\"ruleName\":\"无糖\",\"price\":0},{\"ruleId\":5,\"ruleName\":\"少糖\",\"price\":1},{\"ruleId\":6,\"ruleName\":\"多糖\",\"price\":2}]}],\"skus\":[{\"skuId\":1,\"state\":1,\"rules\":[{\"specId\":1,\"specName\":\"温度\",\"ruleId\":1,\"ruleName\":\"常温\",\"price\":0.00},{\"specId\":2,\"specName\":\"糖度\",\"ruleId\":3,\"ruleName\":\"无糖\",\"price\":0.00}]},{\"skuId\":1,\"state\":1,\"rules\":[{\"specId\":1,\"specName\":\"温度\",\"ruleId\":2,\"ruleName\":\"冰\",\"price\":2.00},{\"specId\":2,\"specName\":\"糖度\",\"ruleId\":3,\"ruleName\":\"无糖\",\"price\":0.00}]},{\"skuId\":1,\"state\":1,\"rules\":[{\"specId\":1,\"specName\":\"温度\",\"ruleId\":1,\"ruleName\":\"常温\",\"price\":0.00},{\"specId\":2,\"specName\":\"糖度\",\"ruleId\":3,\"ruleName\":\"加糖\",\"price\":2.00}]},{\"skuId\":1,\"state\":1,\"rules\":[{\"specId\":1,\"specName\":\"温度\",\"ruleId\":1,\"ruleName\":\"冰\",\"price\":2.00},{\"specId\":2,\"specName\":\"糖度\",\"ruleId\":3,\"ruleName\":\"加糖\",\"price\":4.00}]}]}", Goods.class);
        Goods g20 = objectMapper.readValue("{\"goodId\":100,\"name\":\"冰茶咖啡\",\"price\":29.9,\"discount\":19.9,\"pics\":{\"thumbnail\":\"https://img1.baidu.com/it/u=3426268058,1014861135&fm=253&fmt=auto&app=138&f=JPEG?w=190&h=118\",\"introImages\":[\"https://nimg.ws.126.net/?url=http%3A%2F%2Fdingyue.ws.126.net%2F2021%2F0916%2F2ff161bap00qzik7b00aad000t700inp.png&thumbnail=660x2147483647&quality=80&type=jpg\"],\"detailImages\":[\"https://nimg.ws.126.net/?url=http%3A%2F%2Fdingyue.ws.126.net%2F2021%2F0916%2F5527f996p00qzikdu00avd000th00inp.png&thumbnail=660x2147483647&quality=80&type=jpg\",\"https://nimg.ws.126.net/?url=http%3A%2F%2Fdingyue.ws.126.net%2F2021%2F0916%2Fbe0a3f04p00qziken00cvd000te00ikp.png&thumbnail=660x2147483647&quality=80&type=jpg\"]},\"desc\":\"\",\"remark\":\"\",\"tags\":[\"YYDS\",\"杨幂同款\"],\"specs\":[{\"specId\":1,\"specName\":\"温度\",\"rules\":[{\"ruleId\":1,\"ruleName\":\"常温\",\"price\":0},{\"ruleId\":2,\"ruleName\":\"加冰\",\"price\":2},{\"ruleId\":3,\"ruleName\":\"加热\",\"price\":3}]},{\"specId\":2,\"specName\":\"糖度\",\"rules\":[{\"ruleId\":4,\"ruleName\":\"无糖\",\"price\":0},{\"ruleId\":5,\"ruleName\":\"少糖\",\"price\":1},{\"ruleId\":6,\"ruleName\":\"多糖\",\"price\":2}]}],\"skus\":[{\"skuId\":1,\"state\":1,\"rules\":[{\"specId\":1,\"specName\":\"温度\",\"ruleId\":1,\"ruleName\":\"常温\",\"price\":0.00},{\"specId\":2,\"specName\":\"糖度\",\"ruleId\":3,\"ruleName\":\"无糖\",\"price\":0.00}]},{\"skuId\":1,\"state\":1,\"rules\":[{\"specId\":1,\"specName\":\"温度\",\"ruleId\":2,\"ruleName\":\"冰\",\"price\":2.00},{\"specId\":2,\"specName\":\"糖度\",\"ruleId\":3,\"ruleName\":\"无糖\",\"price\":0.00}]},{\"skuId\":1,\"state\":1,\"rules\":[{\"specId\":1,\"specName\":\"温度\",\"ruleId\":1,\"ruleName\":\"常温\",\"price\":0.00},{\"specId\":2,\"specName\":\"糖度\",\"ruleId\":3,\"ruleName\":\"加糖\",\"price\":2.00}]},{\"skuId\":1,\"state\":1,\"rules\":[{\"specId\":1,\"specName\":\"温度\",\"ruleId\":1,\"ruleName\":\"冰\",\"price\":2.00},{\"specId\":2,\"specName\":\"糖度\",\"ruleId\":3,\"ruleName\":\"加糖\",\"price\":4.00}]}]}", Goods.class);
        Goods g21 = objectMapper.readValue("{\"goodId\":100,\"name\":\"冰茶咖啡\",\"price\":29.9,\"discount\":19.9,\"pics\":{\"thumbnail\":\"https://img1.baidu.com/it/u=3426268058,1014861135&fm=253&fmt=auto&app=138&f=JPEG?w=190&h=118\",\"introImages\":[\"https://nimg.ws.126.net/?url=http%3A%2F%2Fdingyue.ws.126.net%2F2021%2F0916%2F2ff161bap00qzik7b00aad000t700inp.png&thumbnail=660x2147483647&quality=80&type=jpg\"],\"detailImages\":[\"https://nimg.ws.126.net/?url=http%3A%2F%2Fdingyue.ws.126.net%2F2021%2F0916%2F5527f996p00qzikdu00avd000th00inp.png&thumbnail=660x2147483647&quality=80&type=jpg\",\"https://nimg.ws.126.net/?url=http%3A%2F%2Fdingyue.ws.126.net%2F2021%2F0916%2Fbe0a3f04p00qziken00cvd000te00ikp.png&thumbnail=660x2147483647&quality=80&type=jpg\"]},\"desc\":\"\",\"remark\":\"\",\"tags\":[\"YYDS\",\"杨幂同款\"],\"specs\":[{\"specId\":1,\"specName\":\"温度\",\"rules\":[{\"ruleId\":1,\"ruleName\":\"常温\",\"price\":0},{\"ruleId\":2,\"ruleName\":\"加冰\",\"price\":2},{\"ruleId\":3,\"ruleName\":\"加热\",\"price\":3}]},{\"specId\":2,\"specName\":\"糖度\",\"rules\":[{\"ruleId\":4,\"ruleName\":\"无糖\",\"price\":0},{\"ruleId\":5,\"ruleName\":\"少糖\",\"price\":1},{\"ruleId\":6,\"ruleName\":\"多糖\",\"price\":2}]}],\"skus\":[{\"skuId\":1,\"state\":1,\"rules\":[{\"specId\":1,\"specName\":\"温度\",\"ruleId\":1,\"ruleName\":\"常温\",\"price\":0.00},{\"specId\":2,\"specName\":\"糖度\",\"ruleId\":3,\"ruleName\":\"无糖\",\"price\":0.00}]},{\"skuId\":1,\"state\":1,\"rules\":[{\"specId\":1,\"specName\":\"温度\",\"ruleId\":2,\"ruleName\":\"冰\",\"price\":2.00},{\"specId\":2,\"specName\":\"糖度\",\"ruleId\":3,\"ruleName\":\"无糖\",\"price\":0.00}]},{\"skuId\":1,\"state\":1,\"rules\":[{\"specId\":1,\"specName\":\"温度\",\"ruleId\":1,\"ruleName\":\"常温\",\"price\":0.00},{\"specId\":2,\"specName\":\"糖度\",\"ruleId\":3,\"ruleName\":\"加糖\",\"price\":2.00}]},{\"skuId\":1,\"state\":1,\"rules\":[{\"specId\":1,\"specName\":\"温度\",\"ruleId\":1,\"ruleName\":\"冰\",\"price\":2.00},{\"specId\":2,\"specName\":\"糖度\",\"ruleId\":3,\"ruleName\":\"加糖\",\"price\":4.00}]}]}", Goods.class);
        Goods g22 = objectMapper.readValue("{\"goodId\":100,\"name\":\"冰茶咖啡\",\"price\":29.9,\"discount\":19.9,\"pics\":{\"thumbnail\":\"https://img1.baidu.com/it/u=3426268058,1014861135&fm=253&fmt=auto&app=138&f=JPEG?w=190&h=118\",\"introImages\":[\"https://nimg.ws.126.net/?url=http%3A%2F%2Fdingyue.ws.126.net%2F2021%2F0916%2F2ff161bap00qzik7b00aad000t700inp.png&thumbnail=660x2147483647&quality=80&type=jpg\"],\"detailImages\":[\"https://nimg.ws.126.net/?url=http%3A%2F%2Fdingyue.ws.126.net%2F2021%2F0916%2F5527f996p00qzikdu00avd000th00inp.png&thumbnail=660x2147483647&quality=80&type=jpg\",\"https://nimg.ws.126.net/?url=http%3A%2F%2Fdingyue.ws.126.net%2F2021%2F0916%2Fbe0a3f04p00qziken00cvd000te00ikp.png&thumbnail=660x2147483647&quality=80&type=jpg\"]},\"desc\":\"\",\"remark\":\"\",\"tags\":[\"YYDS\",\"杨幂同款\"],\"specs\":[{\"specId\":1,\"specName\":\"温度\",\"rules\":[{\"ruleId\":1,\"ruleName\":\"常温\",\"price\":0},{\"ruleId\":2,\"ruleName\":\"加冰\",\"price\":2},{\"ruleId\":3,\"ruleName\":\"加热\",\"price\":3}]},{\"specId\":2,\"specName\":\"糖度\",\"rules\":[{\"ruleId\":4,\"ruleName\":\"无糖\",\"price\":0},{\"ruleId\":5,\"ruleName\":\"少糖\",\"price\":1},{\"ruleId\":6,\"ruleName\":\"多糖\",\"price\":2}]}],\"skus\":[{\"skuId\":1,\"state\":1,\"rules\":[{\"specId\":1,\"specName\":\"温度\",\"ruleId\":1,\"ruleName\":\"常温\",\"price\":0.00},{\"specId\":2,\"specName\":\"糖度\",\"ruleId\":3,\"ruleName\":\"无糖\",\"price\":0.00}]},{\"skuId\":1,\"state\":1,\"rules\":[{\"specId\":1,\"specName\":\"温度\",\"ruleId\":2,\"ruleName\":\"冰\",\"price\":2.00},{\"specId\":2,\"specName\":\"糖度\",\"ruleId\":3,\"ruleName\":\"无糖\",\"price\":0.00}]},{\"skuId\":1,\"state\":1,\"rules\":[{\"specId\":1,\"specName\":\"温度\",\"ruleId\":1,\"ruleName\":\"常温\",\"price\":0.00},{\"specId\":2,\"specName\":\"糖度\",\"ruleId\":3,\"ruleName\":\"加糖\",\"price\":2.00}]},{\"skuId\":1,\"state\":1,\"rules\":[{\"specId\":1,\"specName\":\"温度\",\"ruleId\":1,\"ruleName\":\"冰\",\"price\":2.00},{\"specId\":2,\"specName\":\"糖度\",\"ruleId\":3,\"ruleName\":\"加糖\",\"price\":4.00}]}]}", Goods.class);

        Sku s1 = objectMapper.readValue("{\"skuId\":1,\"state\":1,\"isDefault\":1,\"price\":20.9,\"discount\":19.9,\"rules\":[{\"specId\":1,\"specName\":\"温度\",\"ruleId\":1,\"ruleName\":\"常温\",\"price\":0.00},{\"specId\":2,\"specName\":\"糖度\",\"ruleId\":3,\"ruleName\":\"无糖\",\"price\":0.00}]}", Sku.class);
        Sku s2 = objectMapper.readValue("{\"skuId\":1,\"state\":1,\"isDefault\":1,\"price\":21.9,\"discount\":39.9,\"rules\":[{\"specId\":1,\"specName\":\"温度\",\"ruleId\":1,\"ruleName\":\"冰\",\"price\":2.00},{\"specId\":2,\"specName\":\"糖度\",\"ruleId\":3,\"ruleName\":\"多糖\",\"price\":1.00}]}", Sku.class);
        Sku s3 = objectMapper.readValue("{\"skuId\":1,\"state\":1,\"isDefault\":1,\"price\":22.9,\"discount\":49.9,\"rules\":[{\"specId\":1,\"specName\":\"温度\",\"ruleId\":1,\"ruleName\":\"热\",\"price\":3.00},{\"specId\":2,\"specName\":\"糖度\",\"ruleId\":3,\"ruleName\":\"少糖\",\"price\":4.00}]}", Sku.class);
        Sku s4 = objectMapper.readValue("{\"skuId\":1,\"state\":1,\"isDefault\":1,\"price\":23.9,\"discount\":59.9,\"rules\":[{\"specId\":1,\"specName\":\"温度\",\"ruleId\":1,\"ruleName\":\"不冰\",\"price\":0.00},{\"specId\":2,\"specName\":\"糖度\",\"ruleId\":3,\"ruleName\":\"无糖\",\"price\":0.00}]}", Sku.class);
        Sku s5 = objectMapper.readValue("{\"skuId\":1,\"state\":1,\"isDefault\":1,\"price\":24.9,\"discount\":69.9,\"rules\":[{\"specId\":1,\"specName\":\"温度\",\"ruleId\":1,\"ruleName\":\"不热\",\"price\":0.00},{\"specId\":2,\"specName\":\"糖度\",\"ruleId\":3,\"ruleName\":\"多糖\",\"price\":1.00}]}", Sku.class);


//        g1.setSkus(Arrays.asList(s1, s2, s3));
        g2.setSkus(Arrays.asList(s5, s2, s3));
        g3.setSkus(Arrays.asList(s4, s2));
        g4.setSkus(Arrays.asList(s3, s5));
        g5.setSkus(Arrays.asList(s2, s1));

        Category c1 = new Category(1, "分类一", Arrays.asList(g1, g2, g3));
        Category c2 = new Category(2, "分类二", Arrays.asList(g4, g5, g6, g7, g8));
        Category c3 = new Category(3, "分类三", Arrays.asList(g9, g10));
        Category c4 = new Category(4, "分类四", Arrays.asList(g11));
        Category c5 = new Category(5, "分类五", Arrays.asList(g12, g13, g14, g15, g16, g17, g18, g19, g20, g21, g22));

        Recommend r1 = new Recommend("推荐一", "介绍一介绍一介绍一介绍一介绍一", "https://nimg.ws.126.net/?url=http%3A%2F%2Fdingyue.ws.126.net%2F2021%2F0916%2F2ff161bap00qzik7b00aad000t700inp.png&thumbnail=660x2147483647&quality=80&type=jpg", g1);
        Recommend r2 = new Recommend("推荐二", "介介绍二介绍二绍二介绍二介绍二", "https://nimg.ws.126.net/?url=http%3A%2F%2Fdingyue.ws.126.net%2F2021%2F0916%2F5527f996p00qzikdu00avd000th00inp.png&thumbnail=660x2147483647&quality=80&type=jpg", g2);
        Recommend r3 = new Recommend("推荐三", "推荐三推荐三推荐三推荐三推荐三", "https://nimg.ws.126.net/?url=http%3A%2F%2Fdingyue.ws.126.net%2F2021%2F0916%2Fbe0a3f04p00qziken00cvd000te00ikp.png&thumbnail=660x2147483647&quality=80&type=jpg", g3);
        Recommend r4 = new Recommend("推荐四", "推荐四推荐四推荐四", "https://nimg.ws.126.net/?url=http%3A%2F%2Fdingyue.ws.126.net%2F2021%2F1019%2F3f2df175j00r174rk006vc000us00n4c.jpg&thumbnail=660x2147483647&quality=80&type=jpg", g4);
        Recommend r5 = new Recommend("推荐五", "推荐五推荐五", "https://nimg.ws.126.net/?url=http%3A%2F%2Fdingyue.ws.126.net%2F2021%2F1019%2F7dd6faa1j00r174rk005gc000us00n4c.jpg&thumbnail=660x2147483647&quality=80&type=jpg", g5);

        recommends = Arrays.asList(r1, r2, r3, r4, r5);
        categorys = Arrays.asList(c1, c2, c3, c4, c5);
        scrollGoods = new ArrayList<>();
        categorys.forEach(category -> {
            scrollGoods.add(new ScrollBean(true, category.getName()));

            category.getGoods().forEach(goods -> {
                scrollGoods.add(new ScrollBean(new ScrollBean.ScrollItemBean(goods, category.getName())));
            });
        });

        for (int i = 0; i < scrollGoods.size(); i++) {
            if (scrollGoods.get(i).isHeader) {
                //遍历右侧列表,判断如果是header,则将此header在右侧列表中所在的position添加到集合中
                tPosition.add(i);
            }
        }
    }

    @Override
    protected void onDestroy() {
        super.onDestroy();
        this.unregisterTrolleyReceiver();
    }

    private TrolleyReceiver trolleyReceiver = null;

    private void registerdTrolleyReceiver() {
        if (trolleyReceiver == null) {
            trolleyReceiver = new TrolleyReceiver();
            IntentFilter intentFilter = new IntentFilter();
            intentFilter.addAction(Utils.ADD_GOODS_ACTION);
            intentFilter.addAction(Utils.GOODS_CHANGED_ACTION);
            this.registerReceiver(trolleyReceiver, intentFilter);
        }
    }

    private void unregisterTrolleyReceiver() {
        if (trolleyReceiver != null) {
            this.unregisterReceiver(trolleyReceiver);
            trolleyReceiver = null;
        }
    }

    class TrolleyReceiver extends BroadcastReceiver {
        @Override
        public void onReceive(Context context, Intent intent) {
            if (intent.getAction().equals(Utils.ADD_GOODS_ACTION)) {
                Goods goods = (Goods) intent.getSerializableExtra("goods");
                Sku sku = (Sku) intent.getSerializableExtra("sku");
                Integer count = intent.getIntExtra("count", 1);
                trolleyView.addGoods(goods, sku, count);
            } else if (intent.getAction().equals(Utils.GOODS_CHANGED_ACTION)) {
                trolleyView.goodsChanged();
            } else if (intent.getAction().equals(Utils.CLEAR_GOODS_ACTION)) {
                trolleyView.clearTrolley();
            }
        }
    }
}
